@@ -156,7 +156,7 @@ const struct rig_caps dx77_caps =
     RIG_MODEL(RIG_MODEL_DX77),
     .model_name =       "DX-77",
     .mfg_name =         "Alinco",
-    .version =          BACKEND_VER ".0",
+    .version =          BACKEND_VER ".1",
     .copyright =        "LGPL",
     .status =           RIG_STATUS_STABLE,
     .rig_type =         RIG_TYPE_TRANSCEIVER,
@@ -203,8 +203,20 @@ const struct rig_caps dx77_caps =
         RIG_CHAN_END,
     },
 
-    .rx_range_list1 =  { RIG_FRNG_END, },    /* FIXME: enter region 1 setting */
-    .tx_range_list1 =  { RIG_FRNG_END, },
+    .rx_range_list1 = {
+        {
+            .startf = kHz(500), .endf = MHz(30), .modes = DX77_OTHER_TX_MODES,
+            .low_power = -1, .high_power = -1, RIG_VFO_A, RIG_ANT_NONE
+        },
+        {
+            .startf = kHz(500), .endf = MHz(30), .modes = DX77_AM_TX_MODES,
+            .low_power = -1, .high_power = -1, RIG_VFO_A, RIG_ANT_NONE
+        },
+        RIG_FRNG_END,
+    },
+    .tx_range_list1 = {RIG_FRNG_END,},
+    .tx_range_list2 = {RIG_FRNG_END,},
+
     .rx_range_list2 =
     {
         {kHz(500), MHz(30), DX77_ALL_MODES, -1, -1, DX77_VFO},
