@@ -18,15 +18,11 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <math.h>
 
 #include <hamlib/rig.h>
 #include "serial.h"
@@ -46,165 +42,6 @@
 #define BARRETT_LEVELS (RIG_LEVEL_STRENGTH)
 
 
-int barrett_init(RIG *rig);
-int barrett_cleanup(RIG *rig);
-static int barrett_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
-int barrett_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
-int barrett_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
-static int barrett_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt);
-int barrett_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
-int barrett_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
-                     pbwidth_t *width);
-
-int barrett_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq);
-int barrett_set_split_vfo(RIG *rig, vfo_t rxvfo, split_t split,
-                          vfo_t txvfo);
-
-int barrett_get_split_vfo(RIG *rig, vfo_t rxvfo, split_t *split,
-                          vfo_t *txvfo);
-
-static int barrett_get_level(RIG *rig, vfo_t vfo, setting_t level,
-                             value_t *val);
-
-static const char *barrett_get_info(RIG *rig);
-
-
-const struct rig_caps barrett_caps =
-{
-    RIG_MODEL(RIG_MODEL_BARRETT_2050),
-    .model_name =       "2050",
-    .mfg_name =         "Barrett",
-    .version =          BACKEND_VER ".0",
-    .copyright =        "LGPL",
-    .status =           RIG_STATUS_STABLE,
-    .rig_type =         RIG_TYPE_TRANSCEIVER,
-    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
-    .ptt_type =         RIG_PTT_RIG,
-    .dcd_type =         RIG_DCD_NONE,
-    .port_type =        RIG_PORT_SERIAL,
-    .serial_rate_min =  9600,
-    .serial_rate_max =  9600,
-    .serial_data_bits = 8,
-    .serial_stop_bits = 1,
-    .serial_parity =    RIG_PARITY_NONE,
-    .serial_handshake = RIG_HANDSHAKE_XONXOFF,
-    .write_delay =      0,
-    .post_write_delay = 50,
-    .timeout =          1000,
-    .retry =            3,
-
-    .has_get_func =     RIG_FUNC_NONE,
-    .has_set_func =     RIG_FUNC_NONE,
-    .has_get_level =    BARRETT_LEVELS,
-    .has_set_level =    RIG_LEVEL_NONE,
-    .has_get_parm =     RIG_PARM_NONE,
-    .has_set_parm =     RIG_PARM_NONE,
-//  .level_gran =          { [LVL_CWPITCH] = { .step = { .i = 10 } } },
-//  .ctcss_list =          common_ctcss_list,
-//  .dcs_list =            full_dcs_list,
-//  2050 does have channels...not implemented yet as no need yet
-//  .chan_list =   {
-//                        {   0,  18, RIG_MTYPE_MEM, DUMMY_MEM_CAP },
-//                        {  19,  19, RIG_MTYPE_CALL },
-//                        {  20,  NB_CHAN-1, RIG_MTYPE_EDGE },
-//                        RIG_CHAN_END,
-//                 },
-// .scan_ops =    DUMMY_SCAN,
-// .vfo_ops =     DUMMY_VFO_OP,
-    .transceive =       RIG_TRN_RIG,
-    .rx_range_list1 = {{
-            .startf = kHz(1600), .endf = MHz(30), .modes = BARRETT_MODES,
-            .low_power = -1, .high_power = -1, BARRETT_VFOS, RIG_ANT_1
-        },
-        RIG_FRNG_END,
-    },
-    .rx_range_list2 = {RIG_FRNG_END,},
-    .tx_range_list1 = {RIG_FRNG_END,},
-    .tx_range_list2 = {RIG_FRNG_END,},
-    .tuning_steps =  { {BARRETT_MODES, 1}, {BARRETT_MODES, RIG_TS_ANY}, RIG_TS_END, },
-    .filters = {
-        {RIG_MODE_SSB | RIG_MODE_CW | RIG_MODE_RTTY, kHz(2.4)},
-        {RIG_MODE_CW, Hz(500)},
-        {RIG_MODE_AM, kHz(8)},
-        {RIG_MODE_AM, kHz(2.4)},
-        RIG_FLT_END,
-    },
-    .priv = NULL,
-
-//  .extlevels =    dummy_ext_levels,
-//  .extparms =     dummy_ext_parms,
-//  .cfgparams =    dummy_cfg_params,
-
-    .rig_init =     barrett_init,
-    .rig_cleanup =  barrett_cleanup,
-
-//  .set_conf =     dummy_set_conf,
-//  .get_conf =     dummy_get_conf,
-
-    .set_freq = barrett_set_freq,
-    .get_freq = barrett_get_freq,
-    .set_mode = barrett_set_mode,
-    .get_mode = barrett_get_mode,
-
-//  .set_powerstat =  dummy_set_powerstat,
-//  .get_powerstat =  dummy_get_powerstat,
-//  .set_level =     dummy_set_level,
-    .get_level =    barrett_get_level,
-//  .set_func =      dummy_set_func,
-//  .get_func =      dummy_get_func,
-//  .set_parm =      dummy_set_parm,
-//  .get_parm =      dummy_get_parm,
-//  .set_ext_level = dummy_set_ext_level,
-//  .get_ext_level = dummy_get_ext_level,
-//  .set_ext_parm =  dummy_set_ext_parm,
-//  .get_ext_parm =  dummy_get_ext_parm,
-
-    .get_info =     barrett_get_info,
-    .set_ptt =      barrett_set_ptt,
-    .get_ptt =      barrett_get_ptt,
-//  .get_dcd =    dummy_get_dcd,
-//  .set_rptr_shift =     dummy_set_rptr_shift,
-//  .get_rptr_shift =     dummy_get_rptr_shift,
-//  .set_rptr_offs =      dummy_set_rptr_offs,
-//  .get_rptr_offs =      dummy_get_rptr_offs,
-//  .set_ctcss_tone =     dummy_set_ctcss_tone,
-//  .get_ctcss_tone =     dummy_get_ctcss_tone,
-//  .set_dcs_code =       dummy_set_dcs_code,
-//  .get_dcs_code =       dummy_get_dcs_code,
-//  .set_ctcss_sql =      dummy_set_ctcss_sql,
-//  .get_ctcss_sql =      dummy_get_ctcss_sql,
-//  .set_dcs_sql =        dummy_set_dcs_sql,
-//  .get_dcs_sql =        dummy_get_dcs_sql,
-    .set_split_freq =   barrett_set_split_freq,
-//  .get_split_freq =     dummy_get_split_freq,
-//  .set_split_mode =     dummy_set_split_mode,
-//  .get_split_mode =     dummy_get_split_mode,
-    .set_split_vfo =    barrett_set_split_vfo,
-    .get_split_vfo =    barrett_get_split_vfo,
-//  .set_rit =    dummy_set_rit,
-//  .get_rit =    dummy_get_rit,
-//  .set_xit =    dummy_set_xit,
-//  .get_xit =    dummy_get_xit,
-//  .set_ts =     dummy_set_ts,
-//  .get_ts =     dummy_get_ts,
-//  .set_ant =    dummy_set_ant,
-//  .get_ant =    dummy_get_ant,
-//  .set_bank =   dummy_set_bank,
-//  .set_mem =    dummy_set_mem,
-//  .get_mem =    dummy_get_mem,
-//  .vfo_op =     dummy_vfo_op,
-//  .scan =               dummy_scan,
-//  .send_dtmf =  dummy_send_dtmf,
-//  .recv_dtmf =  dummy_recv_dtmf,
-//  .send_morse =  dummy_send_morse,
-//  .set_channel =        dummy_set_channel,
-//  .get_channel =        dummy_get_channel,
-//  .set_trn =    dummy_set_trn,
-//  .get_trn =    dummy_get_trn,
-//  .power2mW =   dummy_power2mW,
-//  .mW2power =   dummy_mW2power,
-};
-
 
 DECLARE_INITRIG_BACKEND(barrett)
 {
@@ -212,6 +49,7 @@ DECLARE_INITRIG_BACKEND(barrett)
 
     rig_register(&barrett_caps);
     rig_register(&barrett950_caps);
+    rig_register(&barrett4050_caps);
     rig_debug(RIG_DEBUG_VERBOSE, "%s: _init back from rig_register\n", __func__);
 
     return RIG_OK;
@@ -221,7 +59,7 @@ DECLARE_INITRIG_BACKEND(barrett)
 int barrett_transaction(RIG *rig, char *cmd, int expected, char **result)
 {
     char cmd_buf[MAXCMDLEN];
-    int retval, cmd_len;
+    int retval;
     char *p;
     char xon;
     char xoff;
@@ -230,10 +68,10 @@ int barrett_transaction(RIG *rig, char *cmd, int expected, char **result)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: cmd=%s\n", __func__, cmd);
 
-    cmd_len = snprintf(cmd_buf, sizeof(cmd_buf), "%s%s", cmd, EOM);
+    SNPRINTF(cmd_buf, sizeof(cmd_buf), "%s%s", cmd, EOM);
 
     rig_flush(&rs->rigport);
-    retval = write_block(&rs->rigport, cmd_buf, cmd_len);
+    retval = write_block(&rs->rigport, (unsigned char *) cmd_buf, strlen(cmd_buf));
 
     if (retval < 0)
     {
@@ -243,45 +81,46 @@ int barrett_transaction(RIG *rig, char *cmd, int expected, char **result)
     if (expected == 0)
     {
         // response format is 0x11,data...,0x0d,0x0a,0x13
-        retval = read_string(&rs->rigport, priv->ret_data, sizeof(priv->ret_data),
+        retval = read_string(&rs->rigport, (unsigned char *) priv->ret_data,
+                             sizeof(priv->ret_data),
                              "\x11", 1, 0, 1);
         rig_debug(RIG_DEBUG_VERBOSE, "%s: resultlen=%d\n", __func__,
                   (int)strlen(priv->ret_data));
 
         if (retval < 0)
         {
+            rig_debug(RIG_DEBUG_ERR, "%s(%d): error in read_string\n", __func__, __LINE__);
             return retval;
         }
     }
     else
     {
-        retval = read_block(&rs->rigport, priv->ret_data, expected);
+        retval = read_block(&rs->rigport, (unsigned char *) priv->ret_data, expected);
 
         if (retval < 0)
         {
+            rig_debug(RIG_DEBUG_ERR, "%s(%d): error in read_block\n", __func__, __LINE__);
             return retval;
         }
     }
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s: retval=%d\n", __func__, retval);
-    dump_hex((const unsigned char *)priv->ret_data, strlen(priv->ret_data));
     p = priv->ret_data;
     xon = p[0];
     xoff = p[strlen(p) - 1];
 
     if (xon == 0x13 && xoff == 0x11)
     {
-        rig_debug(RIG_DEBUG_ERR, "%s: removing xoff char\n", __func__);
+        //rig_debug(RIG_DEBUG_TRACE, "%s: removing xoff char\n", __func__);
         p[strlen(p) - 1] = 0;
     }
     else
     {
-        rig_debug(RIG_DEBUG_ERR,
+        rig_debug(RIG_DEBUG_WARN,
                   "%s: expected XOFF=0x13 as first and XON=0x11 as last byte, got %02x/%02x\n",
                   __func__, xon, xoff);
     }
 
-    rig_debug(RIG_DEBUG_ERR, "%s: removing xon char\n", __func__);
+    //rig_debug(RIG_DEBUG_ERR, "%s: removing xon char\n", __func__);
     // Remove the XON char if there
     p = memchr(priv->ret_data, 0x11, strlen(priv->ret_data));
 
@@ -322,9 +161,8 @@ int barrett_transaction(RIG *rig, char *cmd, int expected, char **result)
             strtok_r(*result, "\r", &dummy);
         }
 
-        dump_hex((const unsigned char *)*result, strlen(*result));
-        rig_debug(RIG_DEBUG_VERBOSE, "%s: returning result=%s\n", __func__,
-                  *result);
+        //rig_debug(RIG_DEBUG_VERBOSE, "%s: returning result=%s\n", __func__,
+        //          *result);
     }
     else
     {
@@ -417,6 +255,7 @@ int barrett_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 }
 
 
+// TC command does not work on 4050 -- not implemented as of 2022-01-12
 /*
  * barrett_set_freq
  * assumes rig!=NULL, rig->state.priv!=NULL
@@ -426,15 +265,31 @@ int barrett_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     char cmd_buf[MAXCMDLEN];
     int retval;
     struct barrett_priv_data *priv = rig->state.priv;
+    freq_t tfreq;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: vfo=%s freq=%.0f\n", __func__,
               rig_strvfo(vfo), freq);
 
+    retval = rig_get_freq(rig, vfo, &tfreq);
+
+    if (retval != RIG_OK)
+    {
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: get_freq failed: %s\n", __func__,
+                  strerror(retval));
+        return retval;
+    }
+
+    if (tfreq == freq)
+    {
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: freq not changing\n", __func__);
+        return RIG_OK;
+    }
+
     // If we are not explicitly asking for VFO_B then we'll set the receive side also
     if (vfo != RIG_VFO_B)
     {
         char *response = NULL;
-        sprintf((char *) cmd_buf, "TR%08.0f", freq);
+        SNPRINTF((char *) cmd_buf, sizeof(cmd_buf), "TR%08.0f", freq);
         retval = barrett_transaction(rig, cmd_buf, 0, &response);
 
         if (retval < 0)
@@ -456,7 +311,7 @@ int barrett_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     {
 
         char *response = NULL;
-        sprintf((char *) cmd_buf, "TT%08.0f", freq);
+        SNPRINTF((char *) cmd_buf, sizeof(cmd_buf), "TC9999T%08.0f", freq);
         retval = barrett_transaction(rig, cmd_buf, 0, &response);
 
         if (retval < 0)
@@ -491,7 +346,7 @@ int barrett_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     // testing with rigctld worked, but from WSJT-X did not
     // WSJT-X is just a little faster without the network timing
     hl_usleep(100 * 1000);
-    sprintf(cmd_buf, "XP%d", ptt);
+    SNPRINTF(cmd_buf, sizeof(cmd_buf), "XP%d", ptt);
     response = NULL;
     retval = barrett_transaction(rig, cmd_buf, 0, &response);
 
@@ -558,12 +413,29 @@ int barrett_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     char cmd_buf[32], ttmode;
     int retval;
+    rmode_t tmode;
+    pbwidth_t twidth;
 
     //struct tt588_priv_data *priv = (struct tt588_priv_data *) rig->state.priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: vfo=%s mode=%s width=%d\n", __func__,
               rig_strvfo(vfo), rig_strrmode(mode), (int)width);
 
+    retval = rig_get_mode(rig, vfo, &tmode, &twidth);
+
+    if (retval != RIG_OK)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: get_mode failed %s\n", __func__,
+                  strerror(retval));
+    }
+
+    if (tmode == mode)
+    {
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: already mode %s so not changing\n", __func__,
+                  rig_strrmode(mode));
+        return RIG_OK;
+    }
+
     switch (mode)
     {
     case RIG_MODE_USB:
@@ -592,7 +464,7 @@ int barrett_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         return -RIG_EINVAL;
     }
 
-    sprintf((char *) cmd_buf, "XB%c" EOM, ttmode);
+    SNPRINTF((char *) cmd_buf, sizeof(cmd_buf), "TB%c" EOM, ttmode);
 
     retval = barrett_transaction(rig, cmd_buf, 0, NULL);
 
@@ -693,7 +565,7 @@ int barrett_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
     rig_debug(RIG_DEBUG_VERBOSE, "%s: vfo=%s freq=%g\n", __func__,
               rig_strvfo(vfo), tx_freq);
 
-    sprintf((char *) cmd_buf, "TT%08.0f" EOM, tx_freq);
+    SNPRINTF((char *) cmd_buf, sizeof(cmd_buf), "TT%08.0f" EOM, tx_freq);
 
     retval = barrett_transaction(rig, cmd_buf, 0, NULL);
 
@@ -792,20 +664,191 @@ int barrett_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 const char *barrett_get_info(RIG *rig)
 {
     char *response = NULL;
+    char *series;
     int retval;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    retval = barrett_transaction(rig, "IVF", 0, &response);
+    retval = barrett_transaction(rig, "IDR", 0, &response);
 
-    if (retval == RIG_OK)
+    if (retval != RIG_OK)
     {
-        rig_debug(RIG_DEBUG_ERR, "%s: result=%s\n", __func__, response);
+        rig_debug(RIG_DEBUG_WARN, "%s: IDR command failed: %s\n", __func__,
+                  strerror(retval));
     }
     else
     {
-        rig_debug(RIG_DEBUG_VERBOSE, "Software Version %s\n", response);
+        series = "unknown";
+    }
+
+    series = strdup(response);
+    retval = barrett_transaction(rig, "IDS", 0, &response);
+
+    if (retval != RIG_OK)
+    {
+        rig_debug(RIG_DEBUG_WARN, "%s: IDS command failed: %s\n", __func__,
+                  strerror(retval));
+        response = "unknown";
+    }
+
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: Barrett series %s, serial# %s\n", __func__,
+              series, response);
+    retval = barrett_transaction(rig, "IV", 0, &response);
+
+    if (retval != RIG_OK)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: IV failed result=%s\n", __func__, response);
+    }
+    else
+    {
+        rig_debug(RIG_DEBUG_VERBOSE, "Barrett software Version %s\n", response);
     }
 
     return response;
 }
+
+int barrett_open(RIG *rig)
+{
+    ENTERFUNC;
+    barrett_get_info(rig);
+    RETURNFUNC(RIG_OK);
+}
+
+
+const struct rig_caps barrett_caps =
+{
+    RIG_MODEL(RIG_MODEL_BARRETT_2050),
+    .model_name =       "2050",
+    .mfg_name =         "Barrett",
+    .version =          BACKEND_VER ".0",
+    .copyright =        "LGPL",
+    .status =           RIG_STATUS_STABLE,
+    .rig_type =         RIG_TYPE_TRANSCEIVER,
+    .targetable_vfo =   RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
+    .ptt_type =         RIG_PTT_RIG,
+    .dcd_type =         RIG_DCD_NONE,
+    .port_type =        RIG_PORT_SERIAL,
+    .serial_rate_min =  9600,
+    .serial_rate_max =  9600,
+    .serial_data_bits = 8,
+    .serial_stop_bits = 1,
+    .serial_parity =    RIG_PARITY_NONE,
+    .serial_handshake = RIG_HANDSHAKE_XONXOFF,
+    .write_delay =      0,
+    .post_write_delay = 50,
+    .timeout =          1000,
+    .retry =            3,
+
+    .has_get_func =     RIG_FUNC_NONE,
+    .has_set_func =     RIG_FUNC_NONE,
+    .has_get_level =    BARRETT_LEVELS,
+    .has_set_level =    RIG_LEVEL_NONE,
+    .has_get_parm =     RIG_PARM_NONE,
+    .has_set_parm =     RIG_PARM_NONE,
+//  .level_gran =          { [LVL_CWPITCH] = { .step = { .i = 10 } } },
+//  .ctcss_list =          common_ctcss_list,
+//  .dcs_list =            full_dcs_list,
+//  2050 does have channels...not implemented yet as no need yet
+//  .chan_list =   {
+//                        {   0,  18, RIG_MTYPE_MEM, DUMMY_MEM_CAP },
+//                        {  19,  19, RIG_MTYPE_CALL },
+//                        {  20,  NB_CHAN-1, RIG_MTYPE_EDGE },
+//                        RIG_CHAN_END,
+//                 },
+// .scan_ops =    DUMMY_SCAN,
+// .vfo_ops =     DUMMY_VFO_OP,
+    .transceive =       RIG_TRN_RIG,
+    .rx_range_list1 = {{
+            .startf = kHz(1600), .endf = MHz(30), .modes = BARRETT_MODES,
+            .low_power = -1, .high_power = -1, BARRETT_VFOS, RIG_ANT_1
+        },
+        RIG_FRNG_END,
+    },
+    .rx_range_list2 = {RIG_FRNG_END,},
+    .tx_range_list1 = {RIG_FRNG_END,},
+    .tx_range_list2 = {RIG_FRNG_END,},
+    .tuning_steps =  { {BARRETT_MODES, 1}, {BARRETT_MODES, RIG_TS_ANY}, RIG_TS_END, },
+    .filters = {
+        {RIG_MODE_SSB | RIG_MODE_CW | RIG_MODE_RTTY, kHz(2.4)},
+        {RIG_MODE_CW, Hz(500)},
+        {RIG_MODE_AM, kHz(8)},
+        {RIG_MODE_AM, kHz(2.4)},
+        RIG_FLT_END,
+    },
+    .priv = NULL,
+
+//  .extlevels =    dummy_ext_levels,
+//  .extparms =     dummy_ext_parms,
+//  .cfgparams =    dummy_cfg_params,
+
+    .rig_init =     barrett_init,
+    .rig_open =     barrett_open,
+    .rig_cleanup =  barrett_cleanup,
+
+//  .set_conf =     dummy_set_conf,
+//  .get_conf =     dummy_get_conf,
+
+    .set_freq = barrett_set_freq,
+    .get_freq = barrett_get_freq,
+    .set_mode = barrett_set_mode,
+    .get_mode = barrett_get_mode,
+
+//  .set_powerstat =  dummy_set_powerstat,
+//  .get_powerstat =  dummy_get_powerstat,
+//  .set_level =     dummy_set_level,
+    .get_level =    barrett_get_level,
+//  .set_func =      dummy_set_func,
+//  .get_func =      dummy_get_func,
+//  .set_parm =      dummy_set_parm,
+//  .get_parm =      dummy_get_parm,
+//  .set_ext_level = dummy_set_ext_level,
+//  .get_ext_level = dummy_get_ext_level,
+//  .set_ext_parm =  dummy_set_ext_parm,
+//  .get_ext_parm =  dummy_get_ext_parm,
+
+    .get_info =     barrett_get_info,
+    .set_ptt =      barrett_set_ptt,
+    .get_ptt =      barrett_get_ptt,
+//  .get_dcd =    dummy_get_dcd,
+//  .set_rptr_shift =     dummy_set_rptr_shift,
+//  .get_rptr_shift =     dummy_get_rptr_shift,
+//  .set_rptr_offs =      dummy_set_rptr_offs,
+//  .get_rptr_offs =      dummy_get_rptr_offs,
+//  .set_ctcss_tone =     dummy_set_ctcss_tone,
+//  .get_ctcss_tone =     dummy_get_ctcss_tone,
+//  .set_dcs_code =       dummy_set_dcs_code,
+//  .get_dcs_code =       dummy_get_dcs_code,
+//  .set_ctcss_sql =      dummy_set_ctcss_sql,
+//  .get_ctcss_sql =      dummy_get_ctcss_sql,
+//  .set_dcs_sql =        dummy_set_dcs_sql,
+//  .get_dcs_sql =        dummy_get_dcs_sql,
+    .set_split_freq =   barrett_set_split_freq,
+//  .get_split_freq =     dummy_get_split_freq,
+//  .set_split_mode =     dummy_set_split_mode,
+//  .get_split_mode =     dummy_get_split_mode,
+    .set_split_vfo =    barrett_set_split_vfo,
+    .get_split_vfo =    barrett_get_split_vfo,
+//  .set_rit =    dummy_set_rit,
+//  .get_rit =    dummy_get_rit,
+//  .set_xit =    dummy_set_xit,
+//  .get_xit =    dummy_get_xit,
+//  .set_ts =     dummy_set_ts,
+//  .get_ts =     dummy_get_ts,
+//  .set_ant =    dummy_set_ant,
+//  .get_ant =    dummy_get_ant,
+//  .set_bank =   dummy_set_bank,
+//  .set_mem =    dummy_set_mem,
+//  .get_mem =    dummy_get_mem,
+//  .vfo_op =     dummy_vfo_op,
+//  .scan =               dummy_scan,
+//  .send_dtmf =  dummy_send_dtmf,
+//  .recv_dtmf =  dummy_recv_dtmf,
+//  .send_morse =  dummy_send_morse,
+//  .set_channel =        dummy_set_channel,
+//  .get_channel =        dummy_get_channel,
+//  .set_trn =    dummy_set_trn,
+//  .get_trn =    dummy_get_trn,
+//  .power2mW =   dummy_power2mW,
+//  .mW2power =   dummy_mW2power,
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
+};
