@@ -812,9 +812,10 @@ static int netrigctl_open(RIG *rig)
             }
             else if (strcmp(setting, "agc_levels") == 0)
             {
-                int i = 1;
+                int i = 0;
                 char *p = strtok(value, " ");
-                rig->caps->agc_levels[0] = RIG_AGC_OFF;
+                rig->caps->agc_levels[0] = RIG_AGC_NONE; // default value gets overwritten
+                rig->caps->agc_level_count = 1;
 
                 while (p)
                 {
@@ -825,6 +826,7 @@ static int netrigctl_open(RIG *rig)
                     if (n == 2)
                     {
                         rig->caps->agc_levels[i++] = agc_code;
+                        rig->caps->agc_level_count++;
                         rig_debug(RIG_DEBUG_VERBOSE, "%s: rig has agc code=%d, level=%s\n", __func__,
                                   agc_code, agc_string);
                     }
@@ -836,8 +838,6 @@ static int netrigctl_open(RIG *rig)
                     rig_debug(RIG_DEBUG_VERBOSE, "%d=%s\n", agc_code, agc_string);
                     p = strtok(NULL, " ");
                 }
-
-                rig->caps->agc_level_count = i;
             }
             else
             {
@@ -1925,6 +1925,8 @@ static int netrigctl_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 
     if (ret != RIG_OK) { return ret; }
 
+    if (strlen(rig_strfunc(func)) == 0) { return -RIG_ENAVAIL; }
+
     SNPRINTF(cmd, sizeof(cmd), "u%s %s\n", vfostr, rig_strfunc(func));
 
     ret = netrigctl_transaction(rig, cmd, strlen(cmd), buf);
@@ -2734,7 +2736,7 @@ struct rig_caps netrigctl_caps =
     RIG_MODEL(RIG_MODEL_NETRIGCTL),
     .model_name =     "NET rigctl",
     .mfg_name =       "Hamlib",
-    .version =        "20221214.0",
+    .version =        "20230106.0",
     .copyright =      "LGPL",
     .status =         RIG_STATUS_STABLE,
     .rig_type =       RIG_TYPE_OTHER,
