@@ -19,14 +19,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <stdlib.h>
-#include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
-#include <math.h>
+#include <hamlib/config.h>
 
 #include "hamlib/rig.h"
 #include "flexradio.h"
