@@ -18,15 +18,11 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
-#include <math.h>
 
 #include <hamlib/rig.h>
 #include <serial.h>
@@ -136,7 +132,7 @@ int icmarine_init(RIG *rig)
 
     priv_caps = (const struct icmarine_priv_caps *) caps->priv;
 
-    rig->state.priv = (struct icmarine_priv_data *)malloc(sizeof(
+    rig->state.priv = (struct icmarine_priv_data *)calloc(1, sizeof(
                           struct icmarine_priv_data));
 
     if (!rig->state.priv)
@@ -209,7 +205,7 @@ int icmarine_set_conf(RIG *rig, token_t token, const char *val)
     return RIG_OK;
 }
 
-int icmarine_get_conf(RIG *rig, token_t token, char *val)
+int icmarine_get_conf2(RIG *rig, token_t token, char *val, int val_len)
 {
     struct icmarine_priv_data *priv;
 
@@ -218,7 +214,7 @@ int icmarine_get_conf(RIG *rig, token_t token, char *val)
     switch (token)
     {
     case TOK_REMOTEID:
-        sprintf(val, "%u", priv->remote_id);
+        SNPRINTF(val, val_len, "%u", priv->remote_id);
         break;
 
     default:
@@ -228,6 +224,11 @@ int icmarine_get_conf(RIG *rig, token_t token, char *val)
     return RIG_OK;
 }
 
+int icmarine_get_conf(RIG *rig, token_t token, char *val)
+{
+    return icmarine_get_conf2(rig, token, val, 128);
+}
+
 
 /*
  * icmarine_transaction
@@ -247,7 +248,7 @@ int icmarine_transaction(RIG *rig, const char *cmd, const char *param,
     char respbuf[BUFSZ + 1];
     char *p;
     char *strip;
-    int cmd_len = 0;
+    int cmd_len;
     unsigned csum = 0;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: cmd='%s', param=%s\n", __func__, cmd,
@@ -259,10 +260,11 @@ int icmarine_transaction(RIG *rig, const char *cmd, const char *param,
     rig_flush(&rs->rigport);
 
     /* command formatting */
-    cmd_len = snprintf(cmdbuf, BUFSZ, "$PICOA,%02d,%02u,%s",
-                       CONTROLLER_ID,
-                       priv->remote_id,
-                       cmd);
+    SNPRINTF(cmdbuf, BUFSZ, "$PICOA,%02d,%02u,%s",
+             CONTROLLER_ID,
+             priv->remote_id,
+             cmd);
+    cmd_len = strlen(cmdbuf);
 
     if (param)
     {
@@ -278,7 +280,7 @@ int icmarine_transaction(RIG *rig, const char *cmd, const char *param,
     cmd_len += snprintf(cmdbuf + cmd_len, BUFSZ - cmd_len, "*%02X" EOM, csum);
 
     /* I/O */
-    retval = write_block(&rs->rigport, cmdbuf, cmd_len);
+    retval = write_block(&rs->rigport, (unsigned char *) cmdbuf, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -288,7 +290,8 @@ int icmarine_transaction(RIG *rig, const char *cmd, const char *param,
     /*
      * Transceiver sends an echo of cmd followed by a CR/LF
      */
-    retval = read_string(&rs->rigport, respbuf, BUFSZ, LF, strlen(LF));
+    retval = read_string(&rs->rigport, (unsigned char *) respbuf, BUFSZ, LF,
+                         strlen(LF), 0, 1);
 
     if (retval < 0)
     {
@@ -302,7 +305,7 @@ int icmarine_transaction(RIG *rig, const char *cmd, const char *param,
     }
 
     /* check response */
-    if (memcmp(respbuf, "$PICOA,", strlen("$PICOA,")))
+    if (memcmp(respbuf, "$PICOA,", strlen("$PICOA,")) != 0)
     {
         return -RIG_EPROTO;
     }
@@ -363,7 +366,7 @@ int icmarine_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     priv = (struct icmarine_priv_data *)rig->state.priv;
 
-    sprintf(freqbuf, "%.6f", freq / MHz(1));
+    SNPRINTF(freqbuf, sizeof(freqbuf), "%.6f", freq / MHz(1));
 
     /* no error reporting upon TXFREQ failure */
     if (RIG_SPLIT_OFF == priv->split)
@@ -417,7 +420,7 @@ int icmarine_set_tx_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     rig_debug(RIG_DEBUG_TRACE, "%s:\n", __func__);
 
-    sprintf(freqbuf, "%.6f", freq / MHz(1));
+    SNPRINTF(freqbuf, sizeof(freqbuf), "%.6f", freq / MHz(1));
 
     return icmarine_transaction(rig, CMD_TXFREQ, freqbuf, NULL);
 }
@@ -718,17 +721,17 @@ int icmarine_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     switch (level)
     {
     case RIG_LEVEL_AF:
-        sprintf(lvlbuf, "%u", (unsigned)(val.f * 255));
+        SNPRINTF(lvlbuf, sizeof(lvlbuf), "%u", (unsigned)(val.f * 255));
         retval = icmarine_transaction(rig, CMD_AFGAIN, lvlbuf, NULL);
         break;
 
     case RIG_LEVEL_RF:
-        sprintf(lvlbuf, "%u", (unsigned)(val.f * 9));
+        SNPRINTF(lvlbuf, sizeof(lvlbuf), "%u", (unsigned)(val.f * 9));
         retval = icmarine_transaction(rig, CMD_RFGAIN, lvlbuf, NULL);
         break;
 
     case RIG_LEVEL_RFPOWER:
-        sprintf(lvlbuf, "%u", 1 + (unsigned)(val.f * 2));
+        SNPRINTF(lvlbuf, sizeof(lvlbuf), "%u", 1 + (unsigned)(val.f * 2));
         retval = icmarine_transaction(rig, CMD_RFPWR, lvlbuf, NULL);
         break;
 
