@@ -19,9 +19,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <string.h>  /* String function definitions */
 
@@ -46,12 +44,13 @@
  * NB: the frame array must be big enough to hold the frame.
  *      The smallest frame is 6 bytes, the biggest is at least 13 bytes.
  */
-int make_cmd_frame(char frame[], char re_id, char ctrl_id, char cmd, int subcmd,
+int make_cmd_frame(unsigned char frame[], unsigned char re_id,
+                   unsigned char ctrl_id,
+                   unsigned char cmd, int subcmd,
                    const unsigned char *data, int data_len)
 {
     int i = 0;
 
-    ENTERFUNC;
 #if 0
     frame[i++] = PAD;   /* give old rigs a chance to flush their rx buffers */
 #endif
@@ -85,7 +84,7 @@ int make_cmd_frame(char frame[], char re_id, char ctrl_id, char cmd, int subcmd,
 
     frame[i++] = FI;        /* EOM code */
 
-    RETURNFUNC(i);
+    return (i);
 }
 
 int icom_frame_fix_preamble(int frame_len, unsigned char *frame)
@@ -103,7 +102,7 @@ int icom_frame_fix_preamble(int frame_len, unsigned char *frame)
     {
         rig_debug(RIG_DEBUG_WARN, "%s: invalid Icom CI-V frame, no preamble found\n",
                   __func__);
-        RETURNFUNC(-RIG_EPROTO);
+        return (-RIG_EPROTO);
     }
 
     return frame_len;
@@ -121,7 +120,7 @@ int icom_frame_fix_preamble(int frame_len, unsigned char *frame)
  * return RIG_OK if transaction completed,
  * or a negative value otherwise indicating the error.
  */
-int icom_one_transaction(RIG *rig, int cmd, int subcmd,
+int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
                          const unsigned char *payload, int payload_len, unsigned char *data,
                          int *data_len)
 {
@@ -134,7 +133,7 @@ int icom_one_transaction(RIG *rig, int cmd, int subcmd,
     unsigned char buf[200];
     unsigned char sendbuf[MAXFRAMELEN];
     int frm_len, frm_data_len, retval;
-    int ctrl_id;
+    unsigned char ctrl_id;
 
     ENTERFUNC;
     memset(buf, 0, 200);
@@ -145,23 +144,23 @@ int icom_one_transaction(RIG *rig, int cmd, int subcmd,
 
     ctrl_id = priv_caps->serial_full_duplex == 0 ? CTRLID : 0x80;
 
-    frm_len = make_cmd_frame((char *) sendbuf, priv->re_civ_addr, ctrl_id, cmd,
+    frm_len = make_cmd_frame(sendbuf, priv->re_civ_addr, ctrl_id, cmd,
                              subcmd, payload, payload_len);
 
     /*
      * should check return code and that write wrote cmd_len chars!
      */
-    Hold_Decode(rig);
+    set_transaction_active(rig);
 
     rig_flush(&rs->rigport);
 
     if (data_len) { *data_len = 0; }
 
-    retval = write_block(&rs->rigport, (char *) sendbuf, frm_len);
+    retval = write_block(&rs->rigport, sendbuf, frm_len);
 
     if (retval != RIG_OK)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(retval);
     }
 
@@ -182,28 +181,45 @@ int icom_one_transaction(RIG *rig, int cmd, int subcmd,
         if (retval == -RIG_ETIMEOUT || retval == 0)
         {
             /* Nothing received, CI-V interface is not echoing */
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_BUSERROR);
         }
 
         if (retval < 0)
         {
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             /* Other error, return it */
             RETURNFUNC(retval);
         }
 
         if (retval < 1)
         {
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_EPROTO);
         }
 
+        // we might have 0xfe string during rig wakeup
+        rig_debug(RIG_DEBUG_TRACE, "%s: DEBUG retval=%d, frm_len=%d, cmd=0x%02x\n",
+                  __func__, retval, frm_len, cmd);
+
+        if (retval != frm_len && cmd == C_SET_PWR)
+        {
+            rig_debug(RIG_DEBUG_TRACE, "%s: removing 0xfe power up echo, len=%d", __func__,
+                      frm_len);
+
+            while (buf[2] == 0xfe)
+            {
+                memmove(buf, &buf[1], frm_len--);
+            }
+
+            dump_hex(buf, frm_len);
+        }
+
         switch (buf[retval - 1])
         {
         case COL:
             /* Collision */
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_BUSBUSY);
 
         case FI:
@@ -213,7 +229,7 @@ int icom_one_transaction(RIG *rig, int cmd, int subcmd,
         default:
             /* Timeout after reading at least one character */
             /* Problem on ci-v bus? */
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_BUSERROR);
         }
 
@@ -222,16 +238,16 @@ int icom_one_transaction(RIG *rig, int cmd, int subcmd,
             /* Not the same length??? */
             /* Problem on ci-v bus? */
             /* Someone else got a packet in? */
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_EPROTO);
         }
 
-        if (memcmp(buf, sendbuf, frm_len))
+        if (memcmp(buf, sendbuf, frm_len) != 0)
         {
             /* Frames are different? */
             /* Problem on ci-v bus? */
             /* Someone else got a packet in? */
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_EPROTO);
         }
     }
@@ -241,7 +257,7 @@ int icom_one_transaction(RIG *rig, int cmd, int subcmd,
      */
     if (data_len == NULL)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(RIG_OK);
     }
 
@@ -272,7 +288,7 @@ read_another_frame:
 
     if (frm_len < 0)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         /* RIG_TIMEOUT: timeout getting response, return timeout */
         /* other error: return it */
         RETURNFUNC(frm_len);
@@ -280,7 +296,7 @@ read_another_frame:
 
     if (frm_len < 1)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(-RIG_EPROTO);
     }
 
@@ -288,16 +304,22 @@ read_another_frame:
 
     if (retval < 0)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(retval);
     }
 
     frm_len = retval;
 
+    if (frm_len < 1)
+    {
+        rig_debug(RIG_DEBUG_ERR, "Unexpected frame len=%d\n", frm_len);
+        RETURNFUNC(-RIG_EPROTO);
+    }
+
     switch (buf[frm_len - 1])
     {
     case COL:
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         /* Collision */
         RETURNFUNC(-RIG_BUSBUSY);
 
@@ -306,11 +328,11 @@ read_another_frame:
         break;
 
     case NAK:
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(-RIG_ERJCTED);
 
     default:
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         /* Timeout after reading at least one character */
         /* Problem on ci-v bus? */
         RETURNFUNC(-RIG_EPROTO);
@@ -318,7 +340,7 @@ read_another_frame:
 
     if (frm_len < ACKFRMLEN)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(-RIG_EPROTO);
     }
 
@@ -326,7 +348,7 @@ read_another_frame:
     // e.g. fe fe e0 50 fa fd
     if (frm_len == 6 && NAK == buf[frm_len - 2])
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(-RIG_ERJCTED);
     }
 
@@ -336,7 +358,7 @@ read_another_frame:
     // has to be one of these two now or frame is corrupt
     if (FI != buf[frm_len - 1] && ACK != buf[frm_len - 1])
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(-RIG_BUSBUSY);
     }
 
@@ -344,7 +366,7 @@ read_another_frame:
 
     if (frm_data_len <= 0)
     {
-        Unhold_Decode(rig);
+        set_transaction_inactive(rig);
         RETURNFUNC(-RIG_EPROTO);
     }
 
@@ -361,17 +383,18 @@ read_another_frame:
 
         if (elapsed_ms > rs->rigport.timeout)
         {
-            Unhold_Decode(rig);
+            set_transaction_inactive(rig);
             RETURNFUNC(-RIG_ETIMEOUT);
         }
 
         goto read_another_frame;
     }
 
-    Unhold_Decode(rig);
+    set_transaction_inactive(rig);
 
     *data_len = frm_data_len;
-    memcpy(data, buf + 4, *data_len);
+
+    if (data != NULL && data_len != NULL) { memcpy(data, buf + 4, *data_len); }
 
     /*
      * TODO: check addresses in reply frame
@@ -433,59 +456,83 @@ int icom_transaction(RIG *rig, int cmd, int subcmd,
 }
 
 /* used in read_icom_frame as end of block */
-static const char icom_block_end[2] = {FI, COL};
+static const char icom_block_end[2] = { FI, COL};
 #define icom_block_end_length 2
 
 /*
- * read_icom_frame
- * read a whole CI-V frame (until 0xfd is encountered)
+ * Read a whole CI-V frame (until 0xfd is encountered).
+ *
  * TODO: strips padding/collisions
  * FIXME: check return codes/bytes read
  */
-int read_icom_frame(hamlib_port_t *p, unsigned char rxbuffer[],
-                    int rxbuffer_len)
+static int read_icom_frame_generic(hamlib_port_t *p,
+                                   const unsigned char rxbuffer[],
+                                   size_t rxbuffer_len, int direct)
 {
     int read = 0;
     int retries = 10;
-    char *rx_ptr = (char *)rxbuffer;
+    unsigned char *rx_ptr = (unsigned char *) rxbuffer;
 
-    ENTERFUNC;
     // zeroize the buffer so we can still check contents after timeouts
     memset(rx_ptr, 0, rxbuffer_len);
 
     /*
      * OK, now sometimes we may time out, e.g. the IC7000 can time out
-     * during a PTT operation. So, we will insure that the last thing we
+     * during a PTT operation. So, we will ensure that the last thing we
      * read was a proper end marker - if not, we will try again.
      */
     do
     {
-        int i = read_string(p, rx_ptr, MAXFRAMELEN - read,
-                            icom_block_end, icom_block_end_length);
+        int i;
 
-        if (i < 0) /* die on errors */
+        if (direct)
         {
-            RETURNFUNC(i);
+            i = read_string_direct(p, rx_ptr, MAXFRAMELEN - read,
+                                   icom_block_end, icom_block_end_length, 0, 1);
+        }
+        else
+        {
+            i = read_string(p, rx_ptr, MAXFRAMELEN - read,
+                            icom_block_end, icom_block_end_length, 0, 1);
+        }
+
+        if (i < 0 && i != RIG_BUSBUSY) /* die on errors */
+        {
+            return (i);
         }
 
         if (i == 0) /* nothing read?*/
         {
             if (--retries <= 0) /* Tried enough times? */
             {
-                RETURNFUNC(read);
+                return (read);
             }
         }
 
         /* OK, we got something. add it in and continue */
-        read   += i;
-        rx_ptr += i;
+        if (i > 0)
+        {
+            read   += i;
+            rx_ptr += i;
+        }
     }
     while ((read < rxbuffer_len) && (rxbuffer[read - 1] != FI)
             && (rxbuffer[read - 1] != COL));
 
-    RETURNFUNC(read);
+    return (read);
 }
 
+int read_icom_frame(hamlib_port_t *p, const unsigned char rxbuffer[],
+                    size_t rxbuffer_len)
+{
+    return read_icom_frame_generic(p, rxbuffer, rxbuffer_len, 0);
+}
+
+int read_icom_frame_direct(hamlib_port_t *p, const unsigned char rxbuffer[],
+                           size_t rxbuffer_len)
+{
+    return read_icom_frame_generic(p, rxbuffer, rxbuffer_len, 1);
+}
 
 /*
  * convert mode and width as expressed by Hamlib frontend
@@ -541,11 +588,27 @@ int rig2icom_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width,
 
     case RIG_MODE_USB:  icmode = S_USB; break;
 
-    case RIG_MODE_PKTUSB:  icmode = S_USB; break;
+    case RIG_MODE_PKTUSB:
+        icmode = S_USB;
+
+        if (rig->caps->rig_model == RIG_MODEL_IC7800)
+        {
+            icmode = S_PSK;
+        }
+
+        break;
 
     case RIG_MODE_LSB:  icmode = S_LSB; break;
 
-    case RIG_MODE_PKTLSB:  icmode = S_LSB; break;
+    case RIG_MODE_PKTLSB:
+        icmode = S_LSB;
+
+        if (rig->caps->rig_model == RIG_MODEL_IC7800)
+        {
+            icmode = S_PSKR;
+        }
+
+        break;
 
     case RIG_MODE_RTTY: icmode = S_RTTY; break;
 
@@ -686,9 +749,25 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode,
 
     case S_RTTYR:   *mode = RIG_MODE_RTTYR; break;
 
-    case S_PSK:     *mode = RIG_MODE_PSK; break;
+    case S_PSK:
+        *mode = RIG_MODE_PSK;
 
-    case S_PSKR:    *mode = RIG_MODE_PSKR; break;
+        if (rig->caps->rig_model == RIG_MODEL_IC7800)
+        {
+            *mode = RIG_MODE_PKTUSB;
+        }
+
+        break;
+
+    case S_PSKR:
+        *mode = RIG_MODE_PSKR;
+
+        if (rig->caps->rig_model == RIG_MODEL_IC7800)
+        {
+            *mode = RIG_MODE_PKTLSB;
+        }
+
+        break;
 
     case S_DSTAR:   *mode = RIG_MODE_DSTAR; break;
 
