@@ -207,7 +207,9 @@ const struct rig_caps ic746_caps =
     .has_set_level =  RIG_LEVEL_SET(IC746_LEVEL_ALL),
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_ANN,
-    .level_gran = {
+    .level_gran =
+    {
+#include "level_gran_icom.h"
         // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
         [LVL_KEYSPD] = { .min = { .i = 6 }, .max = { .i = 48 }, .step = { .i = 1 } },
@@ -437,7 +439,9 @@ const struct rig_caps ic746pro_caps =
     .has_set_level =  RIG_LEVEL_SET(IC746_LEVEL_ALL),
     .has_get_parm =  IC746_GET_PARM,
     .has_set_parm =  IC746_SET_PARM,
-    .level_gran = {
+    .level_gran =
+    {
+#include "level_gran_icom.h"
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
     },
     .parm_gran =  {},
