@@ -86,9 +86,9 @@ const struct rig_caps id4100_caps =
     RIG_MODEL(RIG_MODEL_ID4100),
     .model_name = "ID-4100",
     .mfg_name =  "Icom",
-    .version =  BACKEND_VER ".0",
+    .version =  BACKEND_VER ".1",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_ALPHA,
+    .status =  RIG_STATUS_BETA,
     .rig_type =  RIG_TYPE_MOBILE,
     .ptt_type =  RIG_PTT_RIG,
     .dcd_type =  RIG_DCD_RIG,
@@ -159,8 +159,10 @@ const struct rig_caps id4100_caps =
 
     .tuning_steps =     {
         // Rem: no support for changing tuning step
+        {RIG_MODE_ALL, 1},
         RIG_TS_END,
     },
+
     /* mode/filter list, remember: order matters! */
     .filters =  {
         {RIG_MODE_FM | RIG_MODE_AM, kHz(12)},
@@ -185,7 +187,7 @@ const struct rig_caps id4100_caps =
     .get_mode =  icom_get_mode,
     .set_vfo =  icom_set_vfo,
 
-    .set_powerstat = icom_set_powerstat,
+    //.set_powerstat = icom_set_powerstat, // ID-4100 does cannot query power
     .get_powerstat = icom_get_powerstat,
     .decode_event =  icom_decode_event,
 
