@@ -21,15 +21,11 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
-#include <math.h>
 #include <ctype.h>   /* character class tests */
 
 #include "hamlib/rig.h"
@@ -91,7 +87,7 @@ int ic10_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
 transaction:
     rig_flush(&rs->rigport);
 
-    retval = write_block(&rs->rigport, cmd, cmd_len);
+    retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -103,14 +99,15 @@ transaction:
         char buffer[50];
         struct kenwood_priv_data *priv = rig->state.priv;
 
-        if (RIG_OK != (retval = write_block(&rs->rigport, priv->verify_cmd
-                                            , strlen(priv->verify_cmd))))
+        if (RIG_OK != (retval = write_block(&rs->rigport,
+                                            (unsigned char *) priv->verify_cmd, strlen(priv->verify_cmd))))
         {
             return retval;
         }
 
         // this should be the ID response
-        retval = read_string(&rs->rigport, buffer, sizeof(buffer), ";", 1, 0, 1);
+        retval = read_string(&rs->rigport, (unsigned char *) buffer, sizeof(buffer),
+                             ";", 1, 0, 1);
 
         // might be ?; too
         if (buffer[0] == '?' && retry_cmd++ < rs->rigport.retry)
@@ -119,7 +116,7 @@ transaction:
             goto transaction;
         }
 
-        if (strncmp("ID", buffer, 2))
+        if (strncmp("ID", buffer, 2) != 0)
         {
             rig_debug(RIG_DEBUG_ERR, "%s: expected ID response and got %s\n", __func__,
                       buffer);
@@ -129,7 +126,7 @@ transaction:
         return RIG_OK;
     }
 
-    retval = read_string(&rs->rigport, data, 50, ";", 1, 0, 1);
+    retval = read_string(&rs->rigport, (unsigned char *) data, 50, ";", 1, 0, 1);
 
     if (retval == -RIG_ETIMEOUT)
     {
@@ -156,7 +153,7 @@ static int get_ic10_if(RIG *rig, char *data)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    for (i = 0; retval != RIG_OK && i < rig->caps->retry; i++)
+    for (i = 0; retval != RIG_OK && i < rig->state.rigport.retry; i++)
     {
         data_len = 37;
         retval = ic10_transaction(rig, "IF;", 3, data, &data_len);
@@ -187,7 +184,7 @@ static int get_ic10_if(RIG *rig, char *data)
 int ic10_set_vfo(RIG *rig, vfo_t vfo)
 {
     char cmdbuf[6];
-    int cmd_len, retval;
+    int retval;
     char vfo_function;
 
     switch (vfo)
@@ -209,9 +206,9 @@ int ic10_set_vfo(RIG *rig, vfo_t vfo)
         return -RIG_EINVAL;
     }
 
-    cmd_len = sprintf(cmdbuf, "FN%c;", vfo_function);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "FN%c;", vfo_function);
 
-    retval = ic10_transaction(rig, cmdbuf, cmd_len, NULL, 0);
+    retval = ic10_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, 0);
     return retval;
 }
 
@@ -374,7 +371,7 @@ int ic10_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 int ic10_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     char modebuf[6];
-    int mode_len, retval;
+    int retval;
     char mode_letter;
 
     switch (mode)
@@ -397,8 +394,8 @@ int ic10_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         return -RIG_EINVAL;
     }
 
-    mode_len = sprintf(modebuf, "MD%c;", mode_letter);
-    retval = ic10_transaction(rig, modebuf, mode_len, NULL, 0);
+    SNPRINTF(modebuf, sizeof(modebuf), "MD%c;", mode_letter);
+    retval = ic10_transaction(rig, modebuf, strlen(modebuf), NULL, 0);
 
     return retval;
 }
@@ -443,7 +440,7 @@ int ic10_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 int ic10_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     char freqbuf[64];
-    int freq_len, retval;
+    int retval;
     unsigned char vfo_letter;
     vfo_t   tvfo;
 
@@ -471,8 +468,9 @@ int ic10_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     }
 
     // cppcheck-suppress *
-    freq_len = sprintf(freqbuf, "F%c%011"PRIll";", vfo_letter, (int64_t)freq);
-    retval = ic10_transaction(rig, freqbuf, freq_len, NULL, 0);
+    SNPRINTF(freqbuf, sizeof(freqbuf), "F%c%011"PRIll";", vfo_letter,
+             (int64_t)freq);
+    retval = ic10_transaction(rig, freqbuf, strlen(freqbuf), NULL, 0);
 
     return retval;
 }
@@ -485,11 +483,11 @@ int ic10_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 int ic10_set_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t option)
 {
     char buf[6], ackbuf[64];
-    int len, ack_len, retval;
+    int ack_len, retval;
 
-    len = sprintf(buf, "AN%c;", ant == RIG_ANT_1 ? '1' : '2');
+    SNPRINTF(buf, sizeof(buf), "AN%c;", ant == RIG_ANT_1 ? '1' : '2');
 
-    retval = ic10_transaction(rig, buf, len, ackbuf, &ack_len);
+    retval = ic10_transaction(rig, buf, strlen(buf), ackbuf, &ack_len);
 
     return retval;
 }
@@ -534,7 +532,7 @@ int ic10_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
     struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
     char infobuf[50];
-    int retval, iflen;
+    int retval, iflen, offset;
 
     retval = get_ic10_if(rig, infobuf);
 
@@ -548,8 +546,15 @@ int ic10_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 
     /* IFggmmmkkkhhh snnnzrx yytdfcp */
     /* IFggmmmkkkhhhxxxxxrrrrrssxcctmfcp */
+    /* IFggmmmkkkhhhxxxxxrrrrrssxcctmfcp####  what should be if p13/p14/p15 included  */
+    /* IF00014074000     +00000000003000000 ; QRP QDX bad IF command -- 36 bytes instead of 33 */
+    /* QRP QDX should be 37 bytes but used only 1 byte for p14 instead of 2 bytes */
+    /* 12345678901234567890123456789012345678 */
+    offset = 5;
+    if (iflen == 36) offset = 8; // QRP QDX gets completely bogus length
+    else if (iflen == 37) offset = 9; // just incase somebody does this add p13/p14x2/p15
 
-    *ptt = infobuf[iflen - 5] == '0' ? RIG_PTT_OFF : RIG_PTT_ON;
+    *ptt = infobuf[iflen - offset] == '0' ? RIG_PTT_OFF : RIG_PTT_ON;
 
     return RIG_OK;
 }
@@ -563,7 +568,7 @@ int ic10_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 int ic10_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
     char pttbuf[4];
-    int ptt_len, retval;
+    int retval;
     unsigned char ptt_letter;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
@@ -580,8 +585,8 @@ int ic10_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
         return -RIG_EINVAL;
     }
 
-    ptt_len = sprintf(pttbuf, "%cX;", ptt_letter);
-    retval = ic10_transaction(rig, pttbuf, ptt_len, NULL, 0);
+    SNPRINTF(pttbuf, sizeof(pttbuf), "%cX;", ptt_letter);
+    retval = ic10_transaction(rig, pttbuf, strlen(pttbuf), NULL, 0);
 
     return retval;
 }
@@ -623,11 +628,11 @@ int ic10_get_mem(RIG *rig, vfo_t vfo, int *ch)
 int ic10_set_mem(RIG *rig, vfo_t vfo, int ch)
 {
     char membuf[8], ackbuf[64];
-    int mem_len, ack_len, retval;
+    int ack_len, retval;
 
-    mem_len = sprintf(membuf, "MC%02d;", ch);
+    SNPRINTF(membuf, sizeof(membuf), "MC%02d;", ch);
 
-    retval = ic10_transaction(rig, membuf, mem_len, ackbuf, &ack_len);
+    retval = ic10_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
 
     return retval;
 }
@@ -636,11 +641,11 @@ int ic10_set_mem(RIG *rig, vfo_t vfo, int ch)
 int ic10_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 {
     char membuf[16], infobuf[32];
-    int retval, info_len, len;
+    int retval, info_len;
 
-    len = sprintf(membuf, "MR00%02d;", chan->channel_num);
+    SNPRINTF(membuf, sizeof(membuf), "MR00%02d;", chan->channel_num);
     info_len = 24;
-    retval = ic10_transaction(rig, membuf, len, infobuf, &info_len);
+    retval = ic10_transaction(rig, membuf, strlen(membuf), infobuf, &info_len);
 
     if (retval != RIG_OK)
     {
@@ -680,9 +685,9 @@ int ic10_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     {
         chan->split = 1;
         /* TX VFO (Split channel only) */
-        len = sprintf(membuf, "MR10%02d;", chan->channel_num);
+        SNPRINTF(membuf, sizeof(membuf), "MR10%02d;", chan->channel_num);
         info_len = 24;
-        retval = ic10_transaction(rig, membuf, len, infobuf, &info_len);
+        retval = ic10_transaction(rig, membuf, strlen(membuf), infobuf, &info_len);
 
         if (retval == RIG_OK && info_len > 17)
         {
@@ -733,7 +738,7 @@ int ic10_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 int ic10_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 {
     char membuf[64];
-    int retval, len, md;
+    int retval, md;
     int64_t freq;
 
     freq = (int64_t) chan->freq;
@@ -768,12 +773,12 @@ int ic10_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     }
 
     /* MWnxrrggmmmkkkhhhdzxxxx; */
-    len = sprintf(membuf, "MW0 %02d%011"PRIll"%c0    ;",
-                  chan->channel_num,
-                  freq,
-                  md
-                 );
-    retval = ic10_transaction(rig, membuf, len, NULL, 0);
+    SNPRINTF(membuf, sizeof(membuf), "MW0 %02d%011"PRIll"%c0    ;",
+             chan->channel_num,
+             freq,
+             md
+            );
+    retval = ic10_transaction(rig, membuf, strlen(membuf), NULL, 0);
 
     if (retval != RIG_OK)
     {
@@ -808,12 +813,12 @@ int ic10_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     if (chan->channel_num >= 90)
     {
         /* MWnxrrggmmmkkkhhhdzxxxx; */
-        len = sprintf(membuf, "MW1 %02d%011"PRIll"%c0    ;",
-                      chan->channel_num,
-                      freq,
-                      md
-                     );
-        retval = ic10_transaction(rig, membuf, len, NULL, 0);
+        SNPRINTF(membuf, sizeof(membuf), "MW1 %02d%011"PRIll"%c0    ;",
+                 chan->channel_num,
+                 freq,
+                 md
+                );
+        retval = ic10_transaction(rig, membuf, strlen(membuf), NULL, 0);
 
         // I assume we need to check the retval here -- W9MDB
         // This was found from cppcheck
@@ -836,13 +841,13 @@ int ic10_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 int ic10_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 {
     char cmdbuf[6], fctbuf[50];
-    int cmdlen, fct_len, retval;
+    int fct_len, retval;
 
     fct_len = 4;
 
     switch (func)
     {
-    case RIG_FUNC_LOCK: cmdlen = sprintf(cmdbuf, "LK;"); break;
+    case RIG_FUNC_LOCK: SNPRINTF(cmdbuf, sizeof(cmdbuf), "LK;"); break;
 
     default:
         rig_debug(RIG_DEBUG_ERR, "%s: unsupported get_func %s",
@@ -850,7 +855,7 @@ int ic10_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
         return -RIG_EINVAL;
     }
 
-    retval = ic10_transaction(rig, cmdbuf, cmdlen, fctbuf, &fct_len);
+    retval = ic10_transaction(rig, cmdbuf, strlen(cmdbuf), fctbuf, &fct_len);
 
     if (retval != RIG_OK)
     {
@@ -877,18 +882,12 @@ int ic10_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 int ic10_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 {
     char cmdbuf[4], fctbuf[16], ackbuf[64];
-    int cmdlen, fct_len, ack_len;
+    int ack_len;
 
     switch (func)
     {
     case RIG_FUNC_LOCK:
-        cmdlen = sprintf(cmdbuf, "LK");
-
-        if (cmdlen < 0)
-        {
-            return -RIG_ETRUNC;
-        }
-
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "LK");
         break;
 
     default:
@@ -897,14 +896,9 @@ int ic10_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
         return -RIG_EINVAL;
     }
 
-    fct_len = sprintf(fctbuf, "%s%c;", cmdbuf, status == 0 ? '0' : '1');
+    SNPRINTF(fctbuf, sizeof(fctbuf), "%s%c;", cmdbuf, status == 0 ? '0' : '1');
 
-    if (fct_len < 0)
-    {
-        return -RIG_ETRUNC;
-    }
-
-    return ic10_transaction(rig, fctbuf, fct_len, ackbuf, &ack_len);
+    return ic10_transaction(rig, fctbuf, strlen(fctbuf), ackbuf, &ack_len);
 }
 
 
@@ -915,7 +909,6 @@ int ic10_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 int ic10_set_parm(RIG *rig, setting_t parm, value_t val)
 {
     char cmdbuf[50];
-    int cmd_len;
     int hours;
     int minutes;
     int seconds;
@@ -927,8 +920,8 @@ int ic10_set_parm(RIG *rig, setting_t parm, value_t val)
         hours = minutes / 60;
         seconds = val.i - (minutes * 60);
         minutes = minutes % 60;
-        cmd_len = sprintf(cmdbuf, "CK1%02d%02d%02d;", hours, minutes, seconds);
-        return ic10_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+        SNPRINTF(cmdbuf, sizeof(cmdbuf), "CK1%02d%02d%02d;", hours, minutes, seconds);
+        return ic10_transaction(rig, cmdbuf, strlen(cmdbuf), NULL, NULL);
         break;
 
     default:
@@ -997,11 +990,11 @@ int ic10_get_parm(RIG *rig, setting_t parm, value_t *val)
 int ic10_set_powerstat(RIG *rig, powerstat_t status)
 {
     char pwrbuf[16], ackbuf[64];
-    int pwr_len, ack_len;
+    int ack_len;
 
-    pwr_len = sprintf(pwrbuf, "PS%c;", status == RIG_POWER_ON ? '1' : '0');
+    SNPRINTF(pwrbuf, sizeof(pwrbuf), "PS%c;", status == RIG_POWER_ON ? '1' : '0');
 
-    return ic10_transaction(rig, pwrbuf, pwr_len, ackbuf, &ack_len);
+    return ic10_transaction(rig, pwrbuf, strlen(pwrbuf), ackbuf, &ack_len);
 }
 
 
@@ -1042,11 +1035,11 @@ int ic10_get_powerstat(RIG *rig, powerstat_t *status)
 int ic10_set_trn(RIG *rig, int trn)
 {
     char trnbuf[16], ackbuf[64];
-    int trn_len, ack_len;
+    int ack_len;
 
-    trn_len = sprintf(trnbuf, "AI%c;", trn == RIG_TRN_RIG ? '1' : '0');
+    SNPRINTF(trnbuf, sizeof(trnbuf), "AI%c;", trn == RIG_TRN_RIG ? '1' : '0');
 
-    return ic10_transaction(rig, trnbuf, trn_len, ackbuf, &ack_len);
+    return ic10_transaction(rig, trnbuf, strlen(trnbuf), ackbuf, &ack_len);
 }
 
 
