@@ -20,15 +20,12 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
 #include <string.h>  /* String function definitions */
-#include <unistd.h>  /* UNIX standard function definitions */
 
 #include "hamlib/rig.h"
 #include "kenwood.h"
@@ -243,9 +240,9 @@ th_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     freq_sent = freq_sent >= MHz(470) ? (round(freq_sent / 10000) * 10000) :
                 freq_sent;
     // cppcheck-suppress *
-    sprintf(buf, "FQ %011"PRIll",%X", (int64_t) freq_sent, step);
+    SNPRINTF(buf, sizeof(buf), "FQ %011"PRIll",%X", (int64_t) freq_sent, step);
 
-    return kenwood_transaction(rig, buf, buf, sizeof buf);
+    return kenwood_transaction(rig, buf, buf, sizeof(buf));
 }
 
 /*
@@ -335,9 +332,9 @@ th_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         }
     }
 
-    sprintf(mdbuf, "MD %c", kmode);
+    SNPRINTF(mdbuf, sizeof(mdbuf), "MD %c", kmode);
 
-    return kenwood_transaction(rig, mdbuf, mdbuf, sizeof mdbuf);
+    return kenwood_transaction(rig, mdbuf, mdbuf, sizeof(mdbuf));
 }
 
 /*
@@ -435,19 +432,19 @@ th_set_vfo(RIG *rig, vfo_t vfo)
         case RIG_VFO_A:
         case RIG_VFO_VFO:
         case RIG_VFO_MAIN:
-            strncpy(cmd, "BC 0", sizeof cmd);
+            strncpy(cmd, "BC 0", sizeof(cmd));
             break;
 
         case RIG_VFO_B:
         case RIG_VFO_SUB:
-            strncpy(cmd, "BC 1", sizeof cmd);
+            strncpy(cmd, "BC 1", sizeof(cmd));
             break;
 
         default:
             return kenwood_wrong_vfo(__func__, vfo);
         }
 
-        return kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+        return kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
     }
 
     /* No "VMC" cmd on THD72A/THD74 */
@@ -463,17 +460,17 @@ th_set_vfo(RIG *rig, vfo_t vfo)
     case RIG_VFO_A:
     case RIG_VFO_VFO:
     case RIG_VFO_MAIN:
-        strncpy(cmd, "VMC 0,0", sizeof cmd);
+        strncpy(cmd, "VMC 0,0", sizeof(cmd));
         break;
 
     case RIG_VFO_B:
     case RIG_VFO_SUB:
-        strncpy(cmd, "VMC 1,0", sizeof cmd);
+        strncpy(cmd, "VMC 1,0", sizeof(cmd));
         break;
 
     case RIG_VFO_MEM:
-        strncpy(cmd, "BC", sizeof cmd);
-        retval = kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+        strncpy(cmd, "BC", sizeof(cmd));
+        retval = kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
 
         if (retval != RIG_OK)
         {
@@ -483,11 +480,11 @@ th_set_vfo(RIG *rig, vfo_t vfo)
         if (rig->caps->rig_model == RIG_MODEL_THF7E ||
                 rig->caps->rig_model == RIG_MODEL_THF6A)
         {
-            snprintf(cmd, sizeof cmd, "VMC %c,1", cmd[3]);
+            SNPRINTF(cmd, sizeof(cmd), "VMC %c,1", cmd[3]);
         }
         else
         {
-            snprintf(cmd, sizeof cmd, "VMC %c,2", cmd[3]);
+            SNPRINTF(cmd, sizeof(cmd), "VMC %c,2", cmd[3]);
         }
 
         break;
@@ -496,7 +493,7 @@ th_set_vfo(RIG *rig, vfo_t vfo)
         return kenwood_wrong_vfo(__func__, vfo);
     }
 
-    return kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+    return kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
 }
 
 int
@@ -570,7 +567,7 @@ th_get_vfo_char(RIG *rig, vfo_t *vfo, char *vfoch)
 
     /* Get mode of the VFO band */
 
-    sprintf(cmdbuf, "VMC %c", vfoc);
+    SNPRINTF(cmdbuf, sizeof(cmdbuf), "VMC %c", vfoc);
 
     retval = kenwood_safe_transaction(rig, cmdbuf, buf, 10, 7);
 
@@ -655,8 +652,8 @@ int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
 
     case RIG_VFO_MEM:
         /* get current band */
-        snprintf(cmd, sizeof cmd, "BC");
-        retval = kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+        SNPRINTF(cmd, sizeof(cmd), "BC");
+        retval = kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
 
         if (retval != RIG_OK)
         {
@@ -672,8 +669,8 @@ int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
         return -RIG_EVFO;
     }
 
-    snprintf(cmd, sizeof cmd, "VMC %d,%d", vfonum, vfomode);
-    retval = kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+    SNPRINTF(cmd, sizeof(cmd), "VMC %d,%d", vfonum, vfomode);
+    retval = kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
 
     if (retval != RIG_OK)
     {
@@ -685,8 +682,8 @@ int tm_set_vfo_bc2(RIG *rig, vfo_t vfo)
         return RIG_OK;
     }
 
-    snprintf(cmd, sizeof cmd, "BC %d,%d", vfonum, txvfonum);
-    return kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+    SNPRINTF(cmd, sizeof(cmd), "BC %d,%d", vfonum, txvfonum);
+    return kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
 }
 
 
@@ -739,15 +736,15 @@ int th_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
     }
 
     /* Set VFO mode. To be done for TX vfo also? */
-    snprintf(vfobuf, sizeof vfobuf, "VMC %d,0", vfonum);
-    retval = kenwood_transaction(rig, vfobuf, vfobuf, sizeof vfobuf);
+    SNPRINTF(vfobuf, sizeof(vfobuf), "VMC %d,0", vfonum);
+    retval = kenwood_transaction(rig, vfobuf, vfobuf, sizeof(vfobuf));
 
     if (retval != RIG_OK)
     {
         return retval;
     }
 
-    snprintf(vfobuf, sizeof vfobuf, "BC %d,%d", vfonum, txvfonum);
+    SNPRINTF(vfobuf, sizeof(vfobuf), "BC %d,%d", vfonum, txvfonum);
     retval = kenwood_transaction(rig, vfobuf, NULL, 0);
 
     if (retval != RIG_OK)
@@ -806,8 +803,8 @@ int
 th_set_trn(RIG *rig, int trn)
 {
     char buf[5];
-    snprintf(buf, sizeof buf, "AI %c", RIG_TRN_RIG == trn ? '1' : '0');
-    return kenwood_transaction(rig, buf, buf, sizeof buf);
+    SNPRINTF(buf, sizeof(buf), "AI %c", RIG_TRN_RIG == trn ? '1' : '0');
+    return kenwood_transaction(rig, buf, buf, sizeof(buf));
 }
 
 /*
@@ -1154,7 +1151,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     switch (level)
     {
     case RIG_LEVEL_RAWSTR:
-        sprintf(buf, "SM %c", vch);
+        SNPRINTF(buf, sizeof(buf), "SM %c", vch);
 
         // XXX use kenwood_safe_transaction
         retval = kenwood_transaction(rig, buf, ackbuf, sizeof(ackbuf));
@@ -1177,7 +1174,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_SQL:
-        sprintf(buf, "SQ %c", vch);
+        SNPRINTF(buf, sizeof(buf), "SQ %c", vch);
         retval = kenwood_safe_transaction(rig, buf, ackbuf, 10, 7);
 
         if (retval != RIG_OK)
@@ -1201,7 +1198,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_AF:
-        sprintf(buf, "AG %c", vch);
+        SNPRINTF(buf, sizeof(buf), "AG %c", vch);
         retval = kenwood_transaction(rig, buf, ackbuf, sizeof(ackbuf));
 
         if (retval != RIG_OK)
@@ -1225,7 +1222,7 @@ th_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         break;
 
     case RIG_LEVEL_RFPOWER:
-        sprintf(buf, "PC %c", vch);
+        SNPRINTF(buf, sizeof(buf), "PC %c", vch);
         retval = kenwood_transaction(rig, buf, ackbuf, sizeof(ackbuf));
 
         if (retval != RIG_OK)
@@ -1345,34 +1342,34 @@ int th_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     {
 
     case RIG_LEVEL_RFPOWER :
-        sprintf(buf, "PC %c,%01d", vch,
-                (int)(val.f * (rig->caps->level_gran[LVL_RFPOWER].max.i -
-                               rig->caps->level_gran[LVL_RFPOWER].min.i))
-                + rig->caps->level_gran[LVL_RFPOWER].min.i);
+        SNPRINTF(buf, sizeof(buf), "PC %c,%01d", vch,
+                 (int)(val.f * (rig->caps->level_gran[LVL_RFPOWER].max.i -
+                                rig->caps->level_gran[LVL_RFPOWER].min.i))
+                 + rig->caps->level_gran[LVL_RFPOWER].min.i);
 
         return kenwood_transaction(rig, buf, NULL, 0);
 
     case RIG_LEVEL_SQL :
-        sprintf(buf, "SQ %c,%02x", vch,
-                (int)(val.f * (rig->caps->level_gran[LVL_SQL].max.i -
-                               rig->caps->level_gran[LVL_SQL].min.i))
-                + rig->caps->level_gran[LVL_SQL].min.i);
+        SNPRINTF(buf, sizeof(buf), "SQ %c,%02x", vch,
+                 (int)(val.f * (rig->caps->level_gran[LVL_SQL].max.i -
+                                rig->caps->level_gran[LVL_SQL].min.i))
+                 + rig->caps->level_gran[LVL_SQL].min.i);
         return kenwood_transaction(rig, buf, NULL, 0);
 
     case RIG_LEVEL_AF :
-        sprintf(buf, "AG %c,%02x", vch, (int)(val.f * 32.0));
+        SNPRINTF(buf, sizeof(buf), "AG %c,%02x", vch, (int)(val.f * 32.0));
         return kenwood_transaction(rig, buf, NULL, 0);
 
     case RIG_LEVEL_ATT :
-        sprintf(buf, "ATT %c", val.i ? '1' : '0');
+        SNPRINTF(buf, sizeof(buf), "ATT %c", val.i ? '1' : '0');
         return kenwood_transaction(rig, buf, NULL, 0);
 
     case RIG_LEVEL_BALANCE :
-        sprintf(buf, "BAL %c", '4' - (int)(val.f * ('4' - '0')));
+        SNPRINTF(buf, sizeof(buf), "BAL %c", '4' - (int)(val.f * ('4' - '0')));
         return kenwood_transaction(rig, buf, NULL, 0);
 
     case RIG_LEVEL_VOXGAIN:
-        sprintf(buf, "VXG %d", (int)(val.f * 9));
+        SNPRINTF(buf, sizeof(buf), "VXG %d", (int)(val.f * 9));
         return kenwood_transaction(rig, buf, NULL, 0);
 
     case RIG_LEVEL_VOXDELAY: /* "VXD" */
@@ -1419,8 +1416,8 @@ th_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
     }
 
     i += (i == 0) ? 1 : 2;  /* Correct for TH-D7A index anomaly */
-    snprintf(tonebuf, sizeof tonebuf, "TN %02d", i);
-    return kenwood_transaction(rig, tonebuf, tonebuf, sizeof tonebuf);
+    SNPRINTF(tonebuf, sizeof(tonebuf), "TN %02d", i);
+    return kenwood_transaction(rig, tonebuf, tonebuf, sizeof(tonebuf));
 }
 
 /*
@@ -1497,8 +1494,8 @@ th_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
     }
 
     i += (i == 0) ? 1 : 2;  /* Correct for TH-D7A index anomaly */
-    snprintf(tonebuf, sizeof tonebuf, "CTN %02d", i);
-    return kenwood_transaction(rig, tonebuf, tonebuf, sizeof tonebuf);
+    SNPRINTF(tonebuf, sizeof(tonebuf), "CTN %02d", i);
+    return kenwood_transaction(rig, tonebuf, tonebuf, sizeof(tonebuf));
 }
 
 /*
@@ -1567,8 +1564,8 @@ th_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
 
     if (code == 0)
     {
-        snprintf(codebuf, sizeof codebuf, "DCS 0");
-        return kenwood_transaction(rig, codebuf, codebuf, sizeof codebuf);
+        SNPRINTF(codebuf, sizeof(codebuf), "DCS 0");
+        return kenwood_transaction(rig, codebuf, codebuf, sizeof(codebuf));
     }
 
     for (i = 0; caps->dcs_list[i] != 0; i++)
@@ -1584,16 +1581,16 @@ th_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
         return -RIG_EINVAL;
     }
 
-    snprintf(codebuf, sizeof codebuf, "DCS 1");
+    SNPRINTF(codebuf, sizeof(codebuf), "DCS 1");
 
     if ((retval = kenwood_transaction(rig, codebuf, codebuf,
-                                      sizeof codebuf)) != RIG_OK)
+                                      sizeof(codebuf))) != RIG_OK)
     {
         return retval;
     }
 
-    snprintf(codebuf, sizeof codebuf, "DCSN %04d", (i + 1) * 10);
-    return kenwood_transaction(rig, codebuf, codebuf, sizeof codebuf);
+    SNPRINTF(codebuf, sizeof(codebuf), "DCSN %04d", (i + 1) * 10);
+    return kenwood_transaction(rig, codebuf, codebuf, sizeof(codebuf));
 }
 
 /*
@@ -1728,8 +1725,8 @@ th_set_mem(RIG *rig, vfo_t vfo, int ch)
         return retval;
     }
 
-    snprintf(membuf, sizeof membuf, "MC %c,%03i", vsel, ch);
-    return kenwood_transaction(rig, membuf, membuf, sizeof membuf);
+    SNPRINTF(membuf, sizeof(membuf), "MC %c,%03i", vsel, ch);
+    return kenwood_transaction(rig, membuf, membuf, sizeof(membuf));
 }
 
 /* Get mem works only when the display is
@@ -1806,7 +1803,7 @@ th_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     char buf[3];
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
     return kenwood_transaction(rig, (ptt == RIG_PTT_ON) ? "TX" : "RX", buf,
-                               sizeof buf);
+                               sizeof(buf));
 }
 
 int th_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
@@ -1949,11 +1946,11 @@ int th_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
         if (chan_caps[1].type == RIG_MTYPE_PRIO)
         {
             /* Info */
-            sprintf(req, "MR %s0,I-%01d", mr_extra, channel_num);
+            SNPRINTF(req, sizeof(req), "MR %s0,I-%01d", mr_extra, channel_num);
         }
         else
         {
-            sprintf(req, "MR %s0,%03d", mr_extra, channel_num);
+            SNPRINTF(req, sizeof(req), "MR %s0,%03d", mr_extra, channel_num);
         }
 
         break;
@@ -1961,13 +1958,13 @@ int th_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     case RIG_MTYPE_EDGE:
         if (chan_caps[1].type == RIG_MTYPE_EDGE)
         {
-            snprintf(req, sizeof(req), "MR %s0,L%01d", mr_extra, channel_num);
-            sprintf(chan->channel_desc, "L%01d", channel_num);
+            SNPRINTF(req, sizeof(req), "MR %s0,L%01d", mr_extra, channel_num);
+            SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "L%01d", channel_num);
         }
         else
         {
-            snprintf(req, sizeof(req), "MR %s0,U%01d", mr_extra, channel_num);
-            sprintf(chan->channel_desc, "U%01d", channel_num);
+            SNPRINTF(req, sizeof(req), "MR %s0,U%01d", mr_extra, channel_num);
+            SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "U%01d", channel_num);
         }
 
         break;
@@ -1975,36 +1972,38 @@ int th_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     case RIG_MTYPE_PRIO:
         if (chan_caps->startc == chan_caps->endc)
         {
-            snprintf(req, sizeof(req), "MR %s0,PR", mr_extra);
-            sprintf(chan->channel_desc, "Pr");
+            SNPRINTF(req, sizeof(req), "MR %s0,PR", mr_extra);
+            SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "Pr");
         }
         else
         {
-            snprintf(req, sizeof(req), "MR %s0,PR%01d", mr_extra, channel_num + 1);
-            sprintf(chan->channel_desc, "Pr%01d", channel_num + 1);
+            SNPRINTF(req, sizeof(req), "MR %s0,PR%01d", mr_extra, channel_num + 1);
+            SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "Pr%01d",
+                     channel_num + 1);
         }
 
         break;
 
     case RIG_MTYPE_CALL:
-        sprintf(req, "CR 0,%01d", channel_num);
+        SNPRINTF(req, sizeof(req), "CR 0,%01d", channel_num);
 
-        if (chan->channel_num == chan_caps->startc) { sprintf(chan->channel_desc, "Call V"); }
-        else if (chan->channel_num == chan_caps->endc) { sprintf(chan->channel_desc, "Call U"); }
-        else { sprintf(chan->channel_desc, "Call"); }
+        if (chan->channel_num == chan_caps->startc) { SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "Call V"); }
+        else if (chan->channel_num == chan_caps->endc) { SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "Call U"); }
+        else { SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "Call"); }
 
         break;
 
     case RIG_MTYPE_BAND:
-        sprintf(req, "VR %01X", channel_num);
-        sprintf(chan->channel_desc, "BAND %01X", channel_num);
+        SNPRINTF(req, sizeof(req), "VR %01X", channel_num);
+        SNPRINTF(chan->channel_desc, sizeof(chan->channel_desc), "BAND %01X",
+                 channel_num);
         break;
 
     default:
         return -RIG_EINVAL;
     }
 
-    sprintf(membuf, "%s", req);
+    SNPRINTF(membuf, sizeof(membuf), "%s", req);
 
     retval = kenwood_transaction(rig, membuf, ackbuf, sizeof(ackbuf));
 
@@ -2140,7 +2139,7 @@ int th_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     {
         /* split ? */
         req[3 + strlen(mr_extra)] = '1';
-        sprintf(membuf, "%s", req);
+        SNPRINTF(membuf, sizeof(membuf), "%s", req);
         retval = kenwood_transaction(rig, membuf, ackbuf, sizeof(ackbuf));
 
         if (retval == RIG_OK)
@@ -2160,11 +2159,11 @@ int th_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 
         if (chan_caps[1].type == RIG_MTYPE_PRIO)
         {
-            sprintf(membuf, "MNA %sI-%01d", mr_extra, channel_num);
+            SNPRINTF(membuf, sizeof(membuf), "MNA %sI-%01d", mr_extra, channel_num);
         }
         else
         {
-            sprintf(membuf, "MNA %s%03d", mr_extra, channel_num);
+            SNPRINTF(membuf, sizeof(membuf), "MNA %s%03d", mr_extra, channel_num);
         }
 
         /* Get memory name */
@@ -2343,13 +2342,13 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         if (chan_caps[1].type == RIG_MTYPE_PRIO)
         {
             /* Info */
-            sprintf(req, "MW %s0,I-%01d", mr_extra, channel_num);
+            SNPRINTF(req, sizeof(req), "MW %s0,I-%01d", mr_extra, channel_num);
             channel_desc = chan->channel_desc;
         }
         else
         {
             /* Regular */
-            sprintf(req, "MW %s0,%03d", mr_extra, channel_num);
+            SNPRINTF(req, sizeof(req), "MW %s0,%03d", mr_extra, channel_num);
             channel_desc = chan->channel_desc;
         }
 
@@ -2358,11 +2357,11 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     case RIG_MTYPE_EDGE:
         if (chan_caps[1].type == RIG_MTYPE_EDGE)
         {
-            sprintf(req, "MW %s0,L%01d", mr_extra, channel_num);
+            SNPRINTF(req, sizeof(req), "MW %s0,L%01d", mr_extra, channel_num);
         }
         else
         {
-            sprintf(req, "MW %s0,U%01d", mr_extra, channel_num);
+            SNPRINTF(req, sizeof(req), "MW %s0,U%01d", mr_extra, channel_num);
         }
 
         break;
@@ -2370,21 +2369,21 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     case RIG_MTYPE_PRIO:
         if (chan_caps->startc == chan_caps->endc)
         {
-            sprintf(req, "MW %s0,PR", mr_extra);
+            SNPRINTF(req, sizeof(req), "MW %s0,PR", mr_extra);
         }
         else
         {
-            sprintf(req, "MW %s0,PR%01d", mr_extra, channel_num + 1);
+            SNPRINTF(req, sizeof(req), "MW %s0,PR%01d", mr_extra, channel_num + 1);
         }
 
         break;
 
     case RIG_MTYPE_CALL:
-        sprintf(req, "CW 0,%01d", channel_num);
+        SNPRINTF(req, sizeof(req), "CW 0,%01d", channel_num);
         break;
 
     case RIG_MTYPE_BAND:
-        sprintf(req, "VW %01X", channel_num);
+        SNPRINTF(req, sizeof(req), "VW %01X", channel_num);
         break;
 
     default:
@@ -2396,7 +2395,7 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 
     if (chan_caps->mem_caps.flags)
     {
-        sprintf(lockoutstr, ",%d", lockout);
+        SNPRINTF(lockoutstr, sizeof(lockoutstr), ",%d", lockout);
     }
     else
     {
@@ -2424,7 +2423,7 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         }
 
         /* Step can be hexa */
-        snprintf(membuf, sizeof(membuf),
+        SNPRINTF(membuf, sizeof(membuf),
                  "%8s,%011"PRIll",%X,%d,%d,%d,%d,%d,%02d,%02d,%03d,%09"PRIll",%d%10s",
                  req, (int64_t)chan->freq, step, shift, rev, tone,
                  ctcss, dcs, tonefq, ctcssfq, dcscode,
@@ -2435,14 +2434,15 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     {
 
         /* Without DCS,mode */
-        sprintf(membuf, "%s,%011"PRIll",%X,%d,%d,%d,%d,,%02d,,%02d,%09"PRIll"%s",
-                req, (int64_t)chan->freq, step, shift, rev, tone,
-                ctcss, tonefq, ctcssfq,
-                (int64_t)labs((long)(chan->rptr_offs)), lockoutstr
-               );
+        SNPRINTF(membuf, sizeof(membuf),
+                 "%s,%011"PRIll",%X,%d,%d,%d,%d,,%02d,,%02d,%09"PRIll"%s",
+                 req, (int64_t)chan->freq, step, shift, rev, tone,
+                 ctcss, tonefq, ctcssfq,
+                 (int64_t)labs((long)(chan->rptr_offs)), lockoutstr
+                );
     }
 
-    retval = kenwood_transaction(rig, membuf, membuf, sizeof membuf);
+    retval = kenwood_transaction(rig, membuf, membuf, sizeof(membuf));
 
     if (retval != RIG_OK)
     {
@@ -2457,8 +2457,9 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 
         req[3 + strlen(mr_extra)] = '1';
 
-        sprintf(membuf, "%s,%011"PRIll",%X", req, (int64_t)chan->tx_freq, step);
-        retval = kenwood_transaction(rig, membuf, membuf, sizeof membuf);
+        SNPRINTF(membuf, sizeof(membuf), "%s,%011"PRIll",%X", req,
+                 (int64_t)chan->tx_freq, step);
+        retval = kenwood_transaction(rig, membuf, membuf, sizeof(membuf));
 
         if (retval != RIG_OK)
         {
@@ -2472,14 +2473,16 @@ int th_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         /* TODO: check strlen(channel_desc) < rig->caps->chan_desc_sz */
         if (chan_caps[1].type == RIG_MTYPE_PRIO)
         {
-            sprintf(membuf, "MNA %sI-%01d,%s", mr_extra, channel_num, channel_desc);
+            SNPRINTF(membuf, sizeof(membuf), "MNA %sI-%01d,%s", mr_extra, channel_num,
+                     channel_desc);
         }
         else
         {
-            sprintf(membuf, "MNA %s%03d,%s", mr_extra, channel_num, channel_desc);
+            SNPRINTF(membuf, sizeof(membuf), "MNA %s%03d,%s", mr_extra, channel_num,
+                     channel_desc);
         }
 
-        retval = kenwood_transaction(rig, membuf, membuf, sizeof membuf);
+        retval = kenwood_transaction(rig, membuf, membuf, sizeof(membuf));
 
         if (retval != RIG_OK)
         {
@@ -2502,22 +2505,22 @@ int th_set_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t option)
     switch (ant)
     {
     case RIG_ANT_1:
-        strncpy(cmd, "ANT 0", sizeof cmd);
+        strncpy(cmd, "ANT 0", sizeof(cmd));
         break;
 
     case RIG_ANT_2:
-        strncpy(cmd, "ANT 1", sizeof cmd);
+        strncpy(cmd, "ANT 1", sizeof(cmd));
         break;
 
     case RIG_ANT_3:
-        strncpy(cmd, "ANT 2", sizeof cmd);
+        strncpy(cmd, "ANT 2", sizeof(cmd));
         break;
 
     default:
         return -RIG_EINVAL;
     }
 
-    return kenwood_transaction(rig, cmd, cmd, sizeof cmd);
+    return kenwood_transaction(rig, cmd, cmd, sizeof(cmd));
 }
 
 
