@@ -19,9 +19,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -153,7 +151,10 @@ const struct rig_caps ts2000_caps =
     .has_set_level =  RIG_LEVEL_SET(TS2000_LEVEL_ALL),
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,    /* FIXME: parms */
-    .level_gran =  {},                 /* FIXME: granularity */
+    .level_gran =
+    {
+#include "level_gran_kenwood.h"
+    },
     .parm_gran =  {},
     .vfo_ops =  TS2000_VFO_OP,
     .scan_ops =  TS2000_SCAN_OP,
@@ -166,6 +167,8 @@ const struct rig_caps ts2000_caps =
     .max_ifshift =  kHz(1),
     .targetable_vfo =  RIG_TARGETABLE_FREQ,
     .transceive =  RIG_TRN_RIG,
+    .agc_level_count = 5,
+    .agc_levels = { RIG_AGC_OFF, RIG_AGC_SLOW, RIG_AGC_MEDIUM, RIG_AGC_FAST, RIG_AGC_ON },
     .bank_qty =   0,
     .chan_desc_sz =  7,
 
@@ -325,6 +328,7 @@ const struct rig_caps ts2000_caps =
     .get_info =  kenwood_get_info,
     .reset =  kenwood_reset,
 
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 /*
@@ -387,7 +391,7 @@ int ts2000_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     }
 
     /* put channel num in the command string */
-    sprintf(cmd, "MR0%03d;", chan->channel_num);
+    SNPRINTF(cmd, sizeof(cmd), "MR0%03d;", chan->channel_num);
 
     err = kenwood_transaction(rig, cmd, buf, sizeof(buf));
 
@@ -761,7 +765,7 @@ int ts2000_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     }
 
     /* P-number       2-3    4 5 6 7   8   9  101112  13 141516  */
-    snprintf(buf, sizeof(buf), "MW0%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;",
+    SNPRINTF(buf, sizeof(buf), "MW0%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;",
              chan->channel_num,
              (unsigned) chan->freq,      /*  4 - frequency */
              '0' + mode,                 /*  5 - mode */
@@ -788,22 +792,22 @@ int ts2000_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 
     if (chan->split == RIG_SPLIT_ON)
     {
-        sprintf(buf, "MW1%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;\n",
-                chan->channel_num,
-                (unsigned) chan->tx_freq,       /*  4 - frequency */
-                '0' + tx_mode,                  /*  5 - mode */
-                (chan->flags & RIG_CHFLAG_SKIP) ? '1' : '0',    /*  6 - lockout status */
-                sqltype,                    /*  7 - squelch and tone type */
-                tone + 1,                   /*  8 - tone code */
-                code + 1,                   /*  9 - CTCSS code */
-                dcscode + 1,                /* 10 - DCS code */
-                (chan->funcs & RIG_FUNC_REV) ? '1' : '0', /* 11 - Reverse status */
-                shift,                      /* 12 - shift type */
-                (int) chan->rptr_offs,              /* 13 - offset frequency */
-                tstep + '0',                        /* 14 - Step size */
-                chan->scan_group + '0',         /* Memory group no */
-                chan->channel_desc              /* 16 - description */
-               );
+        SNPRINTF(buf, sizeof(buf), "MW1%03d%011u%c%c%c%02d%02d%03d%c%c%09d0%c%c%s;\n",
+                 chan->channel_num,
+                 (unsigned) chan->tx_freq,       /*  4 - frequency */
+                 '0' + tx_mode,                  /*  5 - mode */
+                 (chan->flags & RIG_CHFLAG_SKIP) ? '1' : '0',    /*  6 - lockout status */
+                 sqltype,                    /*  7 - squelch and tone type */
+                 tone + 1,                   /*  8 - tone code */
+                 code + 1,                   /*  9 - CTCSS code */
+                 dcscode + 1,                /* 10 - DCS code */
+                 (chan->funcs & RIG_FUNC_REV) ? '1' : '0', /* 11 - Reverse status */
+                 shift,                      /* 12 - shift type */
+                 (int) chan->rptr_offs,              /* 13 - offset frequency */
+                 tstep + '0',                        /* 14 - Step size */
+                 chan->scan_group + '0',         /* Memory group no */
+                 chan->channel_desc              /* 16 - description */
+                );
         rig_debug(RIG_DEBUG_VERBOSE, "Split, the command will be: %s\n", buf);
 
         err = kenwood_transaction(rig, buf, NULL, 0);
