@@ -24,6 +24,7 @@
 
 #include <hamlib/rig.h>
 #include "kenwood.h"
+#include "cal.h"
 
 // TODO: Copied from TS-480, to be verified
 #define TS890_VFO (RIG_VFO_A|RIG_VFO_B)
@@ -36,8 +37,9 @@
 #define TS890_AM_TX_MODES RIG_MODE_AM
 
 // TODO: Copied from TS-480, to be verified
-#define TS890_LEVEL_ALL (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC)
-#define TS890_FUNC_ALL (RIG_FUNC_NB|RIG_FUNC_NB2|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_NR|RIG_FUNC_BC|RIG_FUNC_BC2|RIG_FUNC_RIT|RIG_FUNC_XIT|RIG_FUNC_TUNER|RIG_FUNC_SEND_MORSE)
+#define TS890_LEVEL_SET (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_KEYSPD|RIG_LEVEL_CWPITCH)
+#define TS890_LEVEL_GET (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_KEYSPD|RIG_LEVEL_ALC|RIG_LEVEL_SWR|RIG_LEVEL_COMP_METER|RIG_LEVEL_ID_METER|RIG_LEVEL_VD_METER|RIG_LEVEL_TEMP_METER|RIG_LEVEL_CWPITCH|RIG_LEVEL_RAWSTR|RIG_LEVEL_STRENGTH)
+#define TS890_FUNC_ALL (RIG_FUNC_NB|RIG_FUNC_NB2|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_BC|RIG_FUNC_BC2|RIG_FUNC_RIT|RIG_FUNC_XIT|RIG_FUNC_TUNER|RIG_FUNC_SEND_MORSE)
 
 #define TS890_VFO_OPS (RIG_OP_UP|RIG_OP_DOWN|RIG_OP_BAND_UP|RIG_OP_BAND_DOWN|RIG_OP_CPY|RIG_OP_TUNE)
 
@@ -95,6 +97,19 @@ int kenwood_ts890_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         SNPRINTF(levelbuf, sizeof(levelbuf), "GC%d", kenwood_val);
         break;
 
+    case RIG_LEVEL_CWPITCH:
+
+        // TODO: Merge this and formatting difference into kenwood.c
+        if (val.i < 300 || val.i > 1100)
+        {
+            return -RIG_EINVAL;
+        }
+
+        /* 300 - 1100 Hz -> 000 - 160 */
+        kenwood_val = (val.i - 298) / 5; /* Round to nearest 5Hz */
+        SNPRINTF(levelbuf, sizeof(levelbuf), "PT%03d", kenwood_val);
+        break;
+
     default:
         return kenwood_set_level(rig, vfo, level, val);
     }
@@ -102,6 +117,55 @@ int kenwood_ts890_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     return kenwood_transaction(rig, levelbuf, NULL, 0);
 }
 
+/* Helper to get and parse meter values using RM
+ * Note that we turn readings on, but nothing off.
+ * 'pips' is the number of LED bars lit in the digital meter, max=70
+ */
+static
+int ts890_get_meter_reading(RIG *rig, char meter, int *pips)
+{
+    char reading[9];   /* 8 char + '\0' */
+    int retval;
+    char target[] = "RMx1"; /* Turn on reading this meter */
+
+    target[2] = meter;
+    retval = kenwood_transaction(rig, target, NULL, 0);
+
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
+    /* Read the first value */
+    retval = kenwood_transaction(rig, "RM", reading, sizeof(reading));
+
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
+    /* Find the one we want */
+    while (strncmp(reading, target, 3) != 0)
+    {
+        /* That wasn't it, get the next one */
+        retval = kenwood_transaction(rig, NULL, reading, sizeof(reading));
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        if (reading[0] != target[0] || reading[1] != target[1])
+        {
+            /* Somebody else's data, bail */
+            return -RIG_EPROTO;
+        }
+    }
+
+    sscanf(reading + 3, "%4d", pips);
+    return RIG_OK;
+
+}
 
 int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
@@ -114,6 +178,7 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
     switch (level)
     {
+    // TODO: This doesn't appear in TS890_LEVEL_GET - should it?
     case RIG_LEVEL_VOXDELAY:
         retval = kenwood_safe_transaction(rig, "VD0", ackbuf, sizeof(ackbuf), 6);
 
@@ -219,6 +284,88 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         return RIG_OK;
 
+    case RIG_LEVEL_ALC:
+        retval = ts890_get_meter_reading(rig, '1', &levelint);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        val->f = (float)levelint / 35.0;  /* Half scale [0,35] -> [0.0,1.0] */
+        return RIG_OK;
+
+    case RIG_LEVEL_SWR:
+        retval = ts890_get_meter_reading(rig, '2', &levelint);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        if (rig->caps->swr_cal.size)
+        {
+            val->f = rig_raw2val_float(levelint, &rig->caps->swr_cal);
+        }
+        else
+        {
+            /* Linear approximations of a very non-linear function */
+            if (levelint < 12) { val->f = 1.0 + (float)levelint / 22.0; }
+            else if (levelint < 24) { val->f = 1.5 + (float)(levelint - 11) / 24.0; }
+            else if (levelint < 36) { val->f = 2.0 + (float)(levelint - 23) / 12.0; }
+            else { val->f = 3.0 + (float)(levelint - 35) / 6.0; }
+        }
+
+        return RIG_OK;
+
+    case RIG_LEVEL_COMP_METER:
+        retval = ts890_get_meter_reading(rig, '3', &levelint);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        if (levelint < 21) { val->f = (float)levelint / 2.0; }   /* db */
+        else if (levelint < 51) { val->f = 10.0 + (float)(levelint - 20) / 3.0; }
+        else { val->f = 20.0 + (float)(levelint - 50) / 4.0; }
+
+        return RIG_OK;
+
+    case RIG_LEVEL_ID_METER:
+        retval = ts890_get_meter_reading(rig, '4', &levelint);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        val->f = (20.0 * (float)levelint) / 70.0;   /* amperes */
+        return RIG_OK;
+
+    case RIG_LEVEL_VD_METER:
+        retval = ts890_get_meter_reading(rig, '5', &levelint);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        val->f = (15.0 * (float)levelint) / 65.0;   /* volts */
+        return RIG_OK;
+
+    case RIG_LEVEL_TEMP_METER:
+#if 0
+        retval = ts890_get_meter_reading(rig, '6', &levelint);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+#endif
+        return -RIG_ENIMPL;
+
     default:
         return kenwood_get_level(rig, vfo, level, val);
     }
@@ -231,6 +378,50 @@ static struct kenwood_priv_caps ts890s_priv_caps =
     .cmdtrm = EOM_KEN,
 };
 
+/* S-meter calibration table
+ * The TS-890S has two distinct S-meter curves, selectable
+ * by menu option.  Define both, but since Hamlib has only
+ * one slot, use the the IARU one.
+ * Values taken from TS-890S In-Depth Manual, p. 8
+ */
+/* Meter Type 1 - Kenwood specific (default) */
+#define TS890_SM_CAL2 { 9, \
+  { \
+    { 0, -28 }, \
+    { 3, -26 }, \
+    { 11, -20 }, \
+    { 19, -13 }, \
+    { 27, -7 }, \
+    { 35, 0 }, \
+    { 48, 20 }, \
+    { 59, 40 }, \
+    { 70, 60 }, \
+  } }
+/* Meter Type 2 - IARU Standard */
+#define TS890_SM_CAL1 { 9, \
+  { \
+    { 0, -54 }, \
+    { 3, -48 }, \
+    { 11, -36 }, \
+    { 19, -24 }, \
+    { 27, -12 }, \
+    { 35, 0 }, \
+    { 48, 20 }, \
+    { 59, 40 }, \
+    { 70, 60 }, \
+  } }
+
+/* SWR meter calibration table */
+/* The full scale value reads infinity, so arbitrary */
+#define TS890_SWR_CAL { 5, \
+      { \
+    { 0, 1.0 }, \
+    { 11, 1.5 }, \
+    { 23, 2.0 }, \
+    { 35, 3.0 }, \
+    { 70, 15.0 } \
+      } }
+
 /*
  * TS-890S rig capabilities
  * Copied from ts480_caps, many of the values have not been verified.
@@ -241,7 +432,7 @@ const struct rig_caps ts890s_caps =
     RIG_MODEL(RIG_MODEL_TS890S),
     .model_name = "TS-890S",
     .mfg_name = "Kenwood",
-    .version = BACKEND_VER ".3",
+    .version = BACKEND_VER ".10",
     .copyright = "LGPL",
     .status = RIG_STATUS_STABLE,
     .rig_type = RIG_TYPE_TRANSCEIVER,
@@ -256,15 +447,17 @@ const struct rig_caps ts890s_caps =
     .serial_handshake = RIG_HANDSHAKE_NONE,
     .write_delay = 0,
     .post_write_delay = 0,
-    .timeout = 200,
+    .timeout = 500,
     .retry = 10,
     .preamp = {12, RIG_DBLST_END,},
     .attenuator = {12, RIG_DBLST_END,},
     .max_rit = kHz(9.99),
     .max_xit = kHz(9.99),
     .max_ifshift = Hz(0),
-    .targetable_vfo = RIG_TARGETABLE_FREQ,
+    .targetable_vfo = RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .transceive = RIG_TRN_RIG,
+    .agc_level_count = 5,
+    .agc_levels = { RIG_AGC_OFF, RIG_AGC_SLOW, RIG_AGC_MEDIUM, RIG_AGC_FAST, RIG_AGC_ON },
 
     .rx_range_list1 = {
         {kHz(100),   Hz(59999999), TS890_ALL_MODES, -1, -1, TS890_VFO},
@@ -350,6 +543,9 @@ const struct rig_caps ts890s_caps =
     },
     .vfo_ops = TS890_VFO_OPS,
 
+    .str_cal = TS890_SM_CAL1,
+    .swr_cal = TS890_SWR_CAL,
+
     .priv = (void *)& ts890s_priv_caps,
     .rig_init = kenwood_init,
     .rig_open = kenwood_open,
@@ -378,10 +574,14 @@ const struct rig_caps ts890s_caps =
     .send_morse =  kenwood_send_morse,
     .wait_morse =  rig_wait_morse,
     .scan = kenwood_scan,     /* not working, invalid arguments using rigctl; kenwood_scan does only support on/off and not tone and CTCSS scan */
-    .has_set_level = TS890_LEVEL_ALL,
-    .has_get_level = TS890_LEVEL_ALL,
+    .has_set_level = TS890_LEVEL_SET,
+    .has_get_level = TS890_LEVEL_GET,
     .set_level = kenwood_ts890_set_level,
     .get_level = kenwood_ts890_get_level,
+    .level_gran =
+    {
+#include "level_gran_kenwood.h"
+    },
     .has_get_func = TS890_FUNC_ALL,
     .has_set_func = TS890_FUNC_ALL,
     .set_func = kenwood_set_func,
