@@ -19,9 +19,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -190,7 +188,7 @@ static const struct confparams elektor507_cfg_params[] =
         "10000000", RIG_CONF_NUMERIC, { .n = { 0, MHz(30), 1 } }
     },
     {
-        TOK_XTALCAL, "xtal_cal", "Xtal Cal", "Cristal calibration",
+        TOK_XTALCAL, "xtal_cal", "Xtal Cal", "Crystal calibration",
         "132", RIG_CONF_NUMERIC, { .n = { 0, 255, 1 } }
     },
     { RIG_CONF_END, NULL, }
@@ -361,7 +359,7 @@ const char *elektor507_get_info(RIG *rig)
 {
     static char buf[64];
 
-    sprintf(buf, "Elektor SDR USB w/ FTDI DLL");
+    SNPRINTF(buf, sizeof(buf), "Elektor SDR USB w/ FTDI DLL");
 
     return buf;
 }
@@ -436,7 +434,7 @@ const char *elektor507_get_info(RIG *rig)
     /* always succeeds since libusb-1.0.16 */
     libusb_get_device_descriptor(libusb_get_device(udh), &desc);
 
-    sprintf(buf, "USB dev %04d", desc.bcdDevice);
+    SNPRINTF(buf, sizeof(buf), "USB dev %04d", desc.bcdDevice);
 
     return buf;
 }
@@ -641,7 +639,7 @@ const struct rig_caps elektor507_caps =
     .set_ant =      elektor507_set_ant,
     .get_ant =      elektor507_get_ant,
     .get_info =     elektor507_get_info,
-
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
 
@@ -670,7 +668,7 @@ int elektor507_set_conf(RIG *rig, token_t token, const char *val)
     return RIG_OK;
 }
 
-int elektor507_get_conf(RIG *rig, token_t token, char *val)
+int elektor507_get_conf2(RIG *rig, token_t token, char *val, int val_len)
 {
     struct elektor507_priv_data *priv;
 
@@ -679,11 +677,11 @@ int elektor507_get_conf(RIG *rig, token_t token, char *val)
     switch (token)
     {
     case TOK_OSCFREQ:
-        sprintf(val, "%"PRIfreq, priv->osc_freq * kHz(1));
+        SNPRINTF(val, val_len, "%"PRIfreq, priv->osc_freq * kHz(1));
         break;
 
     case TOK_XTALCAL:
-        sprintf(val, "%u", priv->xtal_cal);
+        SNPRINTF(val, val_len, "%u", priv->xtal_cal);
         break;
 
     default:
@@ -693,6 +691,11 @@ int elektor507_get_conf(RIG *rig, token_t token, char *val)
     return RIG_OK;
 }
 
+int elektor507_get_conf(RIG *rig, token_t token, char *val)
+{
+    return elektor507_get_conf2(rig, token, val, 128);
+}
+
 
 
 int elektor507_open(RIG *rig)
