@@ -317,7 +317,7 @@ const struct rig_caps ft1000mp_caps =
     RIG_MODEL(RIG_MODEL_FT1000MP),
     .model_name =         "FT-1000MP",
     .mfg_name =           "Yaesu",
-    .version =            "20220421.0",
+    .version =            "20230104.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -340,6 +340,10 @@ const struct rig_caps ft1000mp_caps =
     .has_set_level =      RIG_LEVEL_BAND_SELECT, /* as strange as it could be */
     .has_get_parm =       RIG_PARM_NONE,
     .has_set_parm =       RIG_PARM_NONE,
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .ctcss_list =         ft1000mp_ctcss_list,
     .dcs_list =           NULL,
     .vfo_ops =        FT1000MP_VFO_OPS,
@@ -456,7 +460,7 @@ const struct rig_caps ft1000mpmkv_caps =
     RIG_MODEL(RIG_MODEL_FT1000MPMKV),
     .model_name =         "MARK-V FT-1000MP",
     .mfg_name =           "Yaesu",
-    .version =            "20220421.0",
+    .version =            "20230104.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -479,6 +483,10 @@ const struct rig_caps ft1000mpmkv_caps =
     .has_set_level =      RIG_LEVEL_BAND_SELECT, /* as strange as it could be */
     .has_get_parm =       RIG_PARM_NONE,
     .has_set_parm =       RIG_PARM_NONE,
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .ctcss_list =         ft1000mp_ctcss_list,
     .dcs_list =           NULL,
     .vfo_ops =        FT1000MP_VFO_OPS,
@@ -595,7 +603,7 @@ const struct rig_caps ft1000mpmkvfld_caps =
     RIG_MODEL(RIG_MODEL_FT1000MPMKVFLD),
     .model_name =         "MARK-V Field FT-1000MP",
     .mfg_name =           "Yaesu",
-    .version =            "20220421.0",
+    .version =            "20230104.0",
     .copyright =          "LGPL",
     .status =             RIG_STATUS_STABLE,
     .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -618,6 +626,10 @@ const struct rig_caps ft1000mpmkvfld_caps =
     .has_set_level =      RIG_LEVEL_BAND_SELECT, /* as strange as it could be */
     .has_get_parm =       RIG_PARM_NONE,
     .has_set_parm =       RIG_PARM_NONE,
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .ctcss_list =         ft1000mp_ctcss_list,
     .dcs_list =           NULL,
     .vfo_ops =        FT1000MP_VFO_OPS,
@@ -1034,6 +1046,7 @@ static int ft1000mp_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
         break;
 
+    case RIG_MODE_PKTUSB:
     case RIG_MODE_RTTYR:
         cmd_index = FT1000MP_NATIVE_MODE_SET_RTTY_USB;
 
