@@ -138,6 +138,10 @@ const struct rig_caps ft757gx_caps =
     .has_set_level =    RIG_LEVEL_BAND_SELECT,
     .has_get_parm =     RIG_PARM_NONE,
     .has_set_parm =     RIG_PARM_NONE,
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .ctcss_list =       NULL,
     .dcs_list =     NULL,
     .preamp =       { RIG_DBLST_END, },
@@ -191,11 +195,11 @@ const struct rig_caps ft757gx_caps =
     },
 
     /* mode/filter list, .remember =  order matters! */
-    .filters = {
-        RIG_FLT_END,
+    .filters =  {
+        {RIG_MODE_ALL, RIG_FLT_ANY},
+        RIG_FLT_END
     },
 
-
     .priv =         NULL,           /* private data */
 
     .rig_init =     ft757_init,
@@ -251,6 +255,10 @@ const struct rig_caps ft757gx2_caps =
     .has_set_level =    RIG_LEVEL_BAND_SELECT,
     .has_get_parm =     RIG_PARM_NONE,
     .has_set_parm =     RIG_PARM_NONE,
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .vfo_ops =      RIG_OP_CPY | RIG_OP_FROM_VFO | RIG_OP_TO_VFO |
     RIG_OP_UP | RIG_OP_DOWN,
     .ctcss_list =       NULL,
