@@ -410,7 +410,10 @@ const struct rig_caps ft847_caps =
     .has_set_level =  RIG_LEVEL_BAND_SELECT,
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
-    .level_gran =  {},      /* granularity */
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  ft847_ctcss_list,
     .dcs_list =  common_dcs_list,
@@ -565,7 +568,10 @@ const struct rig_caps ft650_caps =
     //.has_set_level =  RIG_LEVEL_BAND_SELECT,
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
-    .level_gran =  {},      /* granularity */
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .parm_gran =  {},
     //.ctcss_list =  ft847_ctcss_list,
     .preamp =   { RIG_DBLST_END, }, /* no preamp/att in CAT */
@@ -620,6 +626,11 @@ const struct rig_caps ft650_caps =
         RIG_FRNG_END,
     }, /* tx range end */
 
+    .tuning_steps =  {
+        {RIG_MODE_ALL, 1},
+        RIG_TS_END,
+    },
+
     /* mode/filter list, .remember =  order matters! */
     .filters =  {
         {RIG_MODE_SSB | RIG_MODE_CW, kHz(2.4)},
@@ -695,7 +706,10 @@ const struct rig_caps mchfqrp_caps =
     .has_set_level =  RIG_LEVEL_BAND_SELECT,
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
-    .level_gran =  {},      /* granularity */
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  ft847_ctcss_list,
     .dcs_list =  common_dcs_list,
@@ -865,7 +879,10 @@ const struct rig_caps ft847uni_caps =
     .has_set_level =  RIG_LEVEL_BAND_SELECT,
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
-    .level_gran =  {},      /* granularity */
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
     .parm_gran =  {},
     .ctcss_list =  ft847_ctcss_list,
     .dcs_list =  common_dcs_list,
