@@ -18,15 +18,10 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <math.h>
 #include <ctype.h>
 
 #include "hamlib/rotator.h"
@@ -183,7 +178,7 @@ transaction_write:
 
     if (cmdstr)
     {
-        retval = write_block(&rs->rotport, cmdstr, strlen(cmdstr));
+        retval = write_block(&rs->rotport, (unsigned char *) cmdstr, strlen(cmdstr));
 
         if (retval != RIG_OK)
         {
@@ -204,13 +199,15 @@ transaction_write:
 
     /* then comes the answer */
     memset(data, 0, data_len);
-    retval = read_string(&rs->rotport, data, data_len, CR, strlen(CR));
+    retval = read_string(&rs->rotport, (unsigned char *) data, data_len, CR,
+                         strlen(CR), 0, 1);
 
     // some models seem to echo -- so we'll check and read again if echoed
     if (cmdstr && strcmp(data, cmdstr) == 0)
     {
         memset(data, 0, data_len);
-        retval = read_string(&rs->rotport, data, data_len, CR, strlen(CR));
+        retval = read_string(&rs->rotport, (unsigned char *) data, data_len, CR,
+                             strlen(CR), 0, 1);
     }
 
     if (retval < 0)
