@@ -48,9 +48,7 @@
  * CAT type control.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -89,7 +87,7 @@ static struct opened_amp_l *opened_amp_list = { NULL };
 static int add_opened_amp(AMP *amp)
 {
     struct opened_amp_l *p;
-    p = (struct opened_amp_l *)malloc(sizeof(struct opened_amp_l));
+    p = (struct opened_amp_l *)calloc(1, sizeof(struct opened_amp_l));
 
     if (!p)
     {
@@ -103,7 +101,7 @@ static int add_opened_amp(AMP *amp)
 }
 
 
-static int remove_opened_amp(AMP *amp)
+static int remove_opened_amp(const AMP *amp)
 {
     struct opened_amp_l *p, *q;
     q = NULL;
@@ -278,6 +276,12 @@ AMP *HAMLIB_API amp_init(amp_model_t amp_model)
         }
     }
 
+    // Now we have to copy our new rig state hamlib_port structure to the deprecated one
+    // Clients built on older 4.X versions will use the old structure
+    // Clients built on newer 4.5 versions will use the new structure
+    memcpy(&amp->state.ampport_deprecated, &amp->state.ampport,
+           sizeof(amp->state.ampport_deprecated));
+
     return amp;
 }
 
@@ -293,7 +297,7 @@ AMP *HAMLIB_API amp_init(amp_model_t amp_model)
  * \return RIG_OK if the operation has been successful, otherwise a **negative
  * value** if an error occurred (in which case, cause is set appropriately).
  *
- * \retval RIG_OK Communication channel succesfully opened.
+ * \retval RIG_OK Communication channel successfully opened.
  * \retval RIG_EINVAL \a amp is NULL or inconsistent.
  *
  * \sa amp_init(), amp_close()
@@ -394,7 +398,6 @@ int HAMLIB_API amp_open(AMP *amp)
         return -RIG_EINVAL;
     }
 
-
     add_opened_amp(amp);
 
     rs->comm_state = 1;
@@ -409,10 +412,15 @@ int HAMLIB_API amp_open(AMP *amp)
 
         if (status != RIG_OK)
         {
+            memcpy(&amp->state.ampport_deprecated, &amp->state.ampport,
+                   sizeof(amp->state.ampport_deprecated));
             return status;
         }
     }
 
+    memcpy(&amp->state.ampport_deprecated, &amp->state.ampport,
+           sizeof(amp->state.ampport_deprecated));
+
     return RIG_OK;
 }
 
@@ -443,6 +451,8 @@ int HAMLIB_API amp_close(AMP *amp)
 
     if (!amp || !amp->caps)
     {
+        amp_debug(RIG_DEBUG_ERR, "%s: NULL ptr? amp=%p, amp->caps=%p\n", __func__, amp,
+                  amp->caps);
         return -RIG_EINVAL;
     }
 
@@ -451,6 +461,8 @@ int HAMLIB_API amp_close(AMP *amp)
 
     if (!rs->comm_state)
     {
+        amp_debug(RIG_DEBUG_ERR, "%s: comm_state=0? rs=%p, rs->comm_state=%d\n",
+                  __func__, rs, rs->comm_state);
         return -RIG_EINVAL;
     }
 
@@ -694,6 +706,43 @@ const char *HAMLIB_API amp_get_info(AMP *amp)
 }
 
 
+/**
+ * \brief Set the value of a requested level.
+ *
+ * \param amp The #AMP handle.
+ * \param level The requested level.
+ * \param val The variable to store the \a level value.
+ *
+ * Set the \a val corresponding to the \a level.
+ *
+ * \note \a val can be any type defined by #value_t.
+ *
+ * \return RIG_OK if the operation was successful, otherwise a **negative
+ * value** if an error occurred (in which case, cause is set appropriately).
+ *
+ * \retval RIG_OK The query was successful.
+ * \retval RIG_EINVAL \a amp is NULL or inconsistent.
+ * \retval RIG_ENAVAIL amp_caps#get_level() capability is not available.
+ *
+ * \sa amp_set_ext_level()
+ */
+int HAMLIB_API amp_set_level(AMP *amp, setting_t level, value_t val)
+{
+    amp_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    if (CHECK_AMP_ARG(amp))
+    {
+        return -RIG_EINVAL;
+    }
+
+    if (amp->caps->set_level == NULL)
+    {
+        return -RIG_ENAVAIL;
+    }
+
+    return amp->caps->set_level(amp, level, val);
+}
+
 /**
  * \brief Query the value of a requested level.
  *
@@ -732,6 +781,41 @@ int HAMLIB_API amp_get_level(AMP *amp, setting_t level, value_t *val)
 }
 
 
+/**
+ * \brief Set the value of a requested extension levels token.
+ *
+ * \param amp The #AMP handle.
+ * \param level The requested extension levels token.
+ * \param val The variable to set the extension \a level token value.
+ *
+ * Query the \a val corresponding to the extension \a level token.
+ *
+ * \return RIG_OK if the operation was successful, otherwise a **negative
+ * value** if an error occurred (in which case, cause is set appropriately).
+ *
+ * \retval RIG_OK The query was successful.
+ * \retval RIG_EINVAL \a amp is NULL or inconsistent.
+ * \retval RIG_ENAVAIL amp_caps#set_ext_level() capability is not available.
+ *
+ * \sa amp_set_level()
+ */
+int HAMLIB_API amp_set_ext_level(AMP *amp, token_t level, value_t val)
+{
+    amp_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    if (CHECK_AMP_ARG(amp))
+    {
+        return -RIG_EINVAL;
+    }
+
+    if (amp->caps->set_ext_level == NULL)
+    {
+        return -RIG_ENAVAIL;
+    }
+
+    return amp->caps->set_ext_level(amp, level, val);
+}
+
 /**
  * \brief Query the value of a requested extension levels token.
  *
