@@ -30,20 +30,14 @@
  * \brief Control Hamlib debugging functions.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
-#include <stdlib.h>
 #include <stdarg.h>
 #include <stdio.h>  /* Standard input/output definitions */
 #include <string.h> /* String function definitions */
-#include <unistd.h> /* UNIX standard function definitions */
 #include <fcntl.h>  /* File control definitions */
 #include <errno.h>  /* Error number definitions */
 #include <sys/types.h>
-#include <unistd.h>
-#include <time.h>
 
 #ifdef ANDROID
 #  include <android/log.h>
@@ -68,7 +62,7 @@
 
 static int rig_debug_level = RIG_DEBUG_TRACE;
 static int rig_debug_time_stamp = 0;
-static FILE *rig_debug_stream;
+FILE *rig_debug_stream;
 static vprintf_cb_t rig_vprintf_cb;
 static rig_ptr_t rig_vprintf_arg;
 
@@ -110,7 +104,7 @@ void dump_hex(const unsigned char ptr[], size_t size)
         if (i % DUMP_HEX_WIDTH == 0)
         {
             /* new line */
-            sprintf(line + 0, "%04x", i);
+            SNPRINTF(line + 0, sizeof(line), "%04x", i);
             memset(line + 4, ' ', sizeof(line) - 4 - 1);
         }
 
@@ -202,6 +196,7 @@ void HAMLIB_API rig_set_debug_time_stamp(int flag)
 void HAMLIB_API rig_debug(enum rig_debug_level_e debug_level,
                           const char *fmt, ...)
 {
+    static pthread_mutex_t client_debug_lock = PTHREAD_MUTEX_INITIALIZER;
     va_list ap;
 
     if (!rig_need_debug(debug_level))
@@ -209,7 +204,7 @@ void HAMLIB_API rig_debug(enum rig_debug_level_e debug_level,
         return;
     }
 
-
+    pthread_mutex_lock(&client_debug_lock);
     va_start(ap, fmt);
 
     if (rig_vprintf_cb)
@@ -226,7 +221,7 @@ void HAMLIB_API rig_debug(enum rig_debug_level_e debug_level,
         if (rig_debug_time_stamp)
         {
             char buf[256];
-            fprintf(rig_debug_stream, "%s: ", date_strget(buf, sizeof(buf)));
+            fprintf(rig_debug_stream, "%s: ", date_strget(buf, sizeof(buf), 1));
         }
 
         vfprintf(rig_debug_stream, fmt, ap);
@@ -270,6 +265,7 @@ void HAMLIB_API rig_debug(enum rig_debug_level_e debug_level,
 
     va_end(ap);
 #endif
+    pthread_mutex_unlock(&client_debug_lock);
 }
 
 
