@@ -1,2 +1,2 @@
 /* This date time is from the last non-merge commit to Hamlib. */
-#define HAMLIBDATETIME "Dec 31 20:46:26Z 2022 SHA=b62099"
+#define HAMLIBDATETIME "Jan 10 01:31:41Z 2023 SHA=921cc5"
