@@ -33,15 +33,16 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <errno.h>   /* Error number definitions */
 
 #include <hamlib/rig.h>
 #include "cal.h"
+#include "misc.h"
 
 
 #ifndef DOC_HIDDEN
@@ -948,4 +949,260 @@ int HAMLIB_API rig_setting2idx(setting_t s)
     return 0;
 }
 
+#include <unistd.h>  /* UNIX standard function definitions */
+
+#if 0
+#include <hamlib/config.h>
+
+#include <stdlib.h>
+#include <stdarg.h>
+#include <stdio.h>   /* Standard input/output definitions */
+#include <string.h>  /* String function definitions */
+
+#ifdef HAVE_SYS_TYPES_H
+#  include <sys/types.h>
+#endif
+
+#ifdef HAVE_SYS_TIME_H
+#  include <sys/time.h>
+#endif
+
+#include <math.h>
+
+#include <hamlib/rig.h>
+#endif
+
+
+#define SETTINGS_FILE "hamlib_settings"
+char settings_file[4096];
+
+HAMLIB_EXPORT(int) rig_settings_get_path(char *path, int pathlen)
+{
+    char cwd[4096];
+
+    if (getcwd(cwd, 4096) == NULL)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: getcwd: %s\n", __func__, strerror(errno));
+        return -RIG_EINTERNAL;
+    }
+
+#ifdef APPLE
+//#include "TargetConditionals.h"
+#ifdef TARGET_OS_IPHONE
+// iOS
+#elif TARGET_IPHONE_SIMULATOR
+// iOS Simulator
+#elif TARGET_OS_MAC
+// Other kinds of Mac OS
+#else
+// Unsupported platform
+#endif
+#endif
+
+    char *xdgpath = getenv("XDG_CONFIG_HOME");
+    char *home = getenv("HOME");
+    snprintf(path, pathlen, "%s/.config", home);
+
+    if (xdgpath)
+    {
+        snprintf(path, pathlen - 1, "%s/%s/%s", xdgpath, cwd, HAMLIB_SETTINGS_FILE);
+    }
+    else if (home && access(path, F_OK) != -1)
+    {
+        snprintf(path, pathlen - 1, "%s/.config/%s", home, HAMLIB_SETTINGS_FILE);
+    }
+    else if (home)
+    {
+        // we add a leading period to hide the file
+        snprintf(path, pathlen - 1, "%s/.%s", home, HAMLIB_SETTINGS_FILE);
+    }
+    else
+    {
+        snprintf(path, pathlen - 1, ".%s", HAMLIB_SETTINGS_FILE);
+    }
+
+    rig_debug(RIG_DEBUG_TRACE, "%s: path=%s\n", __func__, path);
+    return RIG_OK;
+}
+
+/**
+ * \brief Save setting parameter
+ * \param setting
+ * \param value
+ * \return RIG_OK or error
+ *
+ * \sa rig_setting_load()
+ */
+HAMLIB_EXPORT(int) rig_settings_save(char *setting, void *value,
+                                     settings_value_t valuetype)
+{
+    FILE *fp;
+    FILE *fptmp;
+    char path[4096];
+    char buf[4096];
+    char *cvalue = (char *)value;
+    int *ivalue = (int *)value;
+    int n = 0;
+    long *lvalue = (long *) value;
+    float *fvalue = (float *) value;
+    double *dvalue = (double *) value;
+    char *vformat = "Unknown format??";
+    char template[64];
+
+    rig_settings_get_path(path, sizeof(path));
+    fp = fopen(path, "r");
+
+    if (fp == NULL)
+    {
+        rig_debug(RIG_DEBUG_WARN, "%s: %s not found\n", __func__,  path);
+        return -RIG_EIO;
+    }
+
+    strcpy(template, "hamlib_settings_XXXXXX");
+
+    switch (valuetype)
+    {
+    case e_CHAR: cvalue = (char *)value; vformat = "%s=%s\n"; break;
+
+    case e_INT: ivalue = (int *)value; vformat = "%s=%d\n"; break;
+
+    case e_LONG: lvalue = (long *)value; vformat = "%s=%l\n"; break;
+
+    case e_FLOAT: fvalue = (float *)value; vformat = "%s=%f\n"; break;
+
+    case e_DOUBLE: dvalue = (double *)value; vformat = "%s=%f\n"; break;
+
+    default:
+        rig_debug(RIG_DEBUG_ERR, "%s: Unknown valuetype=%d\n", __func__, valuetype);
+    }
+
+    if (fp == NULL)
+    {
+        // first time for this file
+        fp = fopen(settings_file, "w");
+
+        switch (valuetype)
+        {
+        case e_CHAR: fprintf(fp, vformat, setting, cvalue); break;
+
+        case e_INT: fprintf(fp, vformat, setting, *ivalue); break;
+
+        case e_LONG: fprintf(fp, vformat, setting, *lvalue); break;
+
+        case e_FLOAT: fprintf(fp, vformat, setting, *fvalue); break;
+
+        case e_DOUBLE: fprintf(fp, vformat, setting, *dvalue); break;
+
+        default:
+            rig_debug(RIG_DEBUG_ERR, "%s: Unknown valuetype=%d\n", __func__, valuetype);
+        }
+
+        fclose(fp);
+        return RIG_OK;
+    }
+
+    int fd = mkstemp(template);
+    close(fd);
+    fptmp = fopen(template, "w");
+
+    if (fptmp == NULL)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: error opening for write %s: %s\n", __func__,
+                  template, strerror(errno));
+        fclose(fp);
+        return -RIG_EIO;
+    }
+
+    while (fgets(buf, sizeof(buf), fp))
+    {
+        char *tmp = strdup(buf);
+        char *s = strtok(tmp, "=");
+
+        if (buf[0] == '#')
+        {
+            fprintf(fptmp, "%s\n", buf);
+            continue;
+        }
+
+        if (s == NULL)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: unable to parse setting from '%s'\n", __func__,
+                      strtok(buf, "\r\n"));
+            fclose(fp);
+            fclose(fptmp);
+            return -RIG_EINTERNAL;
+        }
+
+        ++n;
+
+        char *v = strtok(NULL, "\r\n");
+
+        if (v == NULL)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: unable to parse value from '%s'\n", __func__,
+                      strtok(buf, "\r\n"));
+            fclose(fp);
+            fclose(fptmp);
+            return -RIG_EINTERNAL;
+        }
+
+        rig_debug(RIG_DEBUG_TRACE, "%s: parsing setting %s=%s\n", __func__, s, v);
+        fprintf(fptmp, vformat, s, value);
+    }
+
+    fclose(fp);
+    fclose(fptmp);
+    remove(settings_file);
+    rename(template, settings_file);
+    rig_debug(RIG_DEBUG_TRACE, "%s: %d settings read\n", __func__, n);
+    return -RIG_ENIMPL;
+}
+
+HAMLIB_EXPORT(int) rig_settings_load(char *setting, void *value,
+                                     settings_value_t valuetype)
+{
+    return -RIG_ENIMPL;
+}
+
+HAMLIB_EXPORT(int) rig_settings_load_all(char *settings_file)
+{
+    FILE *fp;
+    char buf[4096];
+    char settingstmp[4096];
+
+    if (settings_file == NULL)
+    {
+        rig_settings_get_path(settingstmp, sizeof(settingstmp));
+        settings_file = settingstmp;
+    }
+
+    fp = fopen(settings_file, "r");
+
+    if (fp == NULL)
+    {
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: settings_file (%s): %s\n", __func__,
+                  settings_file, strerror(errno));
+        return -RIG_EINVAL;
+    }
+
+    rig_debug(RIG_DEBUG_TRACE, "%s: opened %s\n", __func__, settings_file);
+
+    while (fgets(buf, sizeof(buf), fp))
+    {
+        char *s = strtok(buf, "=");
+        char *v = strtok(NULL, "\r\n");
+
+        if (strcmp(s, "sharedkey") == 0)
+        {
+            char *sharedkey = strdup(v);
+            rig_debug(RIG_DEBUG_TRACE, "%s: settings_file=%s, shared_key=%s\n", __func__,
+                      settings_file, sharedkey);
+            free(sharedkey);
+        }
+    }
+
+    return RIG_OK;
+}
+
+
 /*! @} */
