@@ -30,9 +30,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #include <stdlib.h>
 
