@@ -36,6 +36,31 @@ int range_sanity_check(const struct freq_range_list range_list[], int rx);
 int ts_sanity_check(const struct tuning_step_list tuning_step[]);
 static void dump_chan_caps(const channel_cap_t *chan, FILE *fout);
 
+struct rig_type_s
+{
+    int type;
+    char *description;
+};
+
+struct rig_type_s rig_type[] =
+{
+    {RIG_TYPE_OTHER, "Other"},
+    {RIG_FLAG_RECEIVER, "Receiver"},
+    {RIG_FLAG_TRANSMITTER, "Transmitter"},
+    {RIG_FLAG_SCANNER, "Scanner"},
+    {RIG_FLAG_MOBILE, "Mobile"},
+    {RIG_FLAG_HANDHELD, "Handheld"},
+    {RIG_FLAG_COMPUTER, "Computer"},
+    {RIG_FLAG_TRANSCEIVER, "Transceiver"},
+    {RIG_FLAG_TRUNKING, "Trunking scanner"},
+    {RIG_FLAG_APRS, "APRS"},
+    {RIG_FLAG_TNC, "TNC"},
+    {RIG_FLAG_DXCLUSTER, "DxCluster"},
+    {RIG_FLAG_DXCLUSTER, "DxCluster"},
+    {RIG_FLAG_TUNER, "Tuner"},
+    {-1, "?\n"}
+};
+
 static int print_ext(RIG *rig, const struct confparams *cfp, rig_ptr_t ptr)
 {
     return print_ext_param(cfp, ptr);
@@ -51,10 +76,14 @@ int dumpcaps(RIG *rig, FILE *fout)
     int can_esplit, can_echannel;
     char freqbuf[20];
     int backend_warnings = 0;
-    static char prntbuf[1024];  /* a malloc would be better.. */
+    char warnbuf[4096];
+    char prntbuf[1024];  /* a malloc would be better.. */
     char *label1, *label2, *label3, *label4, *label5;
     char *labelrx1; // , *labelrx2, *labelrx3, *labelrx4, *labelrx5;
 
+    warnbuf[0] = 0;
+    prntbuf[0] = 0;
+
     if (!rig || !rig->caps)
     {
         return -RIG_EINVAL;
@@ -70,50 +99,22 @@ int dumpcaps(RIG *rig, FILE *fout)
     fprintf(fout, "Backend status:\t%s\n", rig_strstatus(caps->status));
     fprintf(fout, "Rig type:\t");
 
-    switch (caps->rig_type & RIG_TYPE_MASK)
+    char *unknown = "Unknown";
+
+    for (i = 0; rig_type[i].type != -1; ++i)
     {
-    case RIG_TYPE_TRANSCEIVER:
-        fprintf(fout, "Transceiver\n");
-        break;
+        if ((rig_type[i].type & caps->rig_type) == rig_type[i].type)
+        {
+            fprintf(fout, "%s ", rig_type[i].description);
+            unknown = "";
+        }
+    }
 
-    case RIG_TYPE_HANDHELD:
-        fprintf(fout, "Handheld\n");
-        break;
+    fprintf(fout, "%s\n", unknown);
 
-    case RIG_TYPE_MOBILE:
-        fprintf(fout, "Mobile\n");
-        break;
-
-    case RIG_TYPE_RECEIVER:
-        fprintf(fout, "Receiver\n");
-        break;
-
-    case RIG_TYPE_PCRECEIVER:
-        fprintf(fout, "PC Receiver\n");
-        break;
-
-    case RIG_TYPE_SCANNER:
-        fprintf(fout, "Scanner\n");
-        break;
-
-    case RIG_TYPE_TRUNKSCANNER:
-        fprintf(fout, "Trunking scanner\n");
-        break;
-
-    case RIG_TYPE_COMPUTER:
-        fprintf(fout, "Computer\n");
-        break;
-
-    case RIG_TYPE_TUNER:
-        fprintf(fout, "Tuner\n");
-        break;
-
-    case RIG_TYPE_OTHER:
-        fprintf(fout, "Other\n");
-        break;
-
-    default:
-        fprintf(fout, "Unknown\n");
+    if (strlen(unknown) > 0)
+    {
+        strcat(warnbuf, " RIG_TYPE");
         backend_warnings++;
     }
 
@@ -147,6 +148,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     default:
         fprintf(fout, "Unknown\n");
+        strcat(warnbuf, " PTT_TYPE");
         backend_warnings++;
     }
 
@@ -180,6 +182,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     default:
         fprintf(fout, "Unknown\n");
+        strcat(warnbuf, " DCD_TYPE");
         backend_warnings++;
     }
 
@@ -230,6 +233,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     default:
         fprintf(fout, "Unknown\n");
+        strcat(warnbuf, " PORT_TYPE");
         backend_warnings++;
     }
 
@@ -291,8 +295,8 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     fprintf(fout, "\n");
 
-    fprintf(fout, "AGC levels:");
 
+    fprintf(fout, "AGC levels:");
     const struct icom_priv_caps *priv_caps =
         (const struct icom_priv_caps *) rig->caps->priv;
 
@@ -308,6 +312,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     }
     else
     {
+
         for (i = 0; i < HAMLIB_MAX_AGC_LEVELS && i < caps->agc_level_count; i++)
         {
             fprintf(fout, " %d=%s", caps->agc_levels[i],
@@ -315,8 +320,13 @@ int dumpcaps(RIG *rig, FILE *fout)
         }
     }
 
+    fprintf(fout, "\n");
+
     if (i == 0)
     {
+        rig_debug(RIG_DEBUG_WARN,
+                  "%s: defaulting to all levels since rig does not have any\n", __func__);
+
         // Fall back to printing out all levels for backwards-compatibility
         for (i = RIG_AGC_OFF; i <= RIG_AGC_LAST; i++)
         {
@@ -384,6 +394,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
         fprintf(fout,
                 "Warning--backend has get RAWSTR, but not calibration data\n");
+        strcat(warnbuf, " RAWSTR_level");
         backend_warnings++;
     }
 
@@ -396,6 +407,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
         //fprintf(fout, "Warning--backend can set readonly levels=0x%0llx\n", caps->has_set_level & RIG_LEVEL_READONLY_LIST);
         fprintf(fout, "Warning--backend can set readonly levels\n");
+        strcat(warnbuf, " READONLY_LEVEL");
         backend_warnings++;
     }
 
@@ -413,6 +425,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     if (caps->has_set_parm & RIG_PARM_READONLY_LIST)
     {
         fprintf(fout, "Warning--backend can set readonly parms!\n");
+        strcat(warnbuf, " READONLY_PARM");
         backend_warnings++;
     }
 
@@ -427,6 +440,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     else
     {
         strcpy(prntbuf, "None. This backend might be bogus!\n");
+        strcat(warnbuf, " MODE_LIST");
         backend_warnings++;
     }
 
@@ -439,6 +453,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     else
     {
         strcpy(prntbuf, "None. This backend might be bogus!\n");
+        strcat(warnbuf, " VFO_LIST");
         backend_warnings++;
     }
 
@@ -531,6 +546,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " TX#1");
         backend_warnings++;
     }
 
@@ -542,6 +558,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " RX#1");
         backend_warnings++;
     }
 
@@ -553,6 +570,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " TX#2");
         backend_warnings++;
     }
 
@@ -564,6 +582,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " RX#2");
         backend_warnings++;
     }
 
@@ -575,6 +594,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " TX#3");
         backend_warnings++;
     }
 
@@ -586,6 +606,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " RX#3");
         backend_warnings++;
     }
 
@@ -597,6 +618,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " TX#4");
         backend_warnings++;
     }
 
@@ -608,6 +630,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " RX#4");
         backend_warnings++;
     }
 
@@ -619,6 +642,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " TX#5");
         backend_warnings++;
     }
 
@@ -630,6 +654,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " RX#5");
         backend_warnings++;
     }
 
@@ -653,6 +678,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     if (i == 0)
     {
         fprintf(fout, " None! This backend might be bogus!");
+        strcat(warnbuf, " TUNING_STEPS");
         backend_warnings++;
     }
 
@@ -662,6 +688,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
     if (status)
     {
+        strcat(warnbuf, " TUNING_SANE");
         backend_warnings++;
     }
 
@@ -685,6 +712,7 @@ int dumpcaps(RIG *rig, FILE *fout)
     if (i == 0)
     {
         fprintf(fout, " None. This backend might be bogus!");
+        strcat(warnbuf, " FILTERS");
         backend_warnings++;
     }
 
@@ -698,7 +726,7 @@ int dumpcaps(RIG *rig, FILE *fout)
 
         if (pbnorm == 0)
         {
-//            continue;
+            continue;
         }
 
         sprintf_freq(freqbuf, sizeof(freqbuf), pbnorm);
@@ -903,7 +931,8 @@ int dumpcaps(RIG *rig, FILE *fout)
     fprintf(fout, "Can get power2mW:\t%c\n", caps->power2mW != NULL ? 'Y' : 'N');
     fprintf(fout, "Can get mW2power:\t%c\n", caps->mW2power != NULL ? 'Y' : 'N');
 
-    fprintf(fout, "\nOverall backend warnings: %d\n", backend_warnings);
+    fprintf(fout, "\nOverall backend warnings: %d %c %s\n", backend_warnings,
+            warnbuf[0] != 0 ? '=' : ' ', warnbuf);
 
     return backend_warnings;
 }
@@ -1017,7 +1046,8 @@ int range_sanity_check(const struct freq_range_list range_list[], int rx)
         }
         else
         {
-            if (!(range_list[i].low_power > 0 && range_list[i].high_power > 0))
+            if (!(range_list[i].low_power >= RIG_FREQ_NONE
+                    && range_list[i].high_power >= RIG_FREQ_NONE))
             {
                 return -3;
             }
