@@ -9,9 +9,7 @@
 
 #include <hamlib/rig.h>
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/config.h>
 
 #define SERIAL_PORT "/dev/ttyS0"
 
